@@ -107,5 +107,5 @@ describe('Prometheus config', () => {
 });
 
 export function selectOption(option: string) {
-  cy.get("[aria-label='Select option']").contains(option).should('be.visible').click();
+  e2e.components.Select.option().contains(option).should('be.visible').click();
 }
