@@ -10,7 +10,8 @@ set -o nounset
 set -o pipefail
 
 SCRIPT_ROOT=$(dirname "${BASH_SOURCE[0]}")/..
-CODEGEN_PKG=${CODEGEN_PKG:-$(cd "${SCRIPT_ROOT}"; ls -d -1 ./vendor/k8s.io/code-generator 2>/dev/null || echo $(go env GOPATH)/pkg/mod/k8s.io/code-generator@v0.29.1)}
+pushd "${SCRIPT_ROOT}/hack" && GO111MODULE=on go mod tidy && popd
+CODEGEN_PKG=${CODEGEN_PKG:-$(cd "${SCRIPT_ROOT}"; ls -d -1 ./vendor/k8s.io/code-generator 2>/dev/null || echo $(go env GOPATH)/pkg/mod/k8s.io/code-generator@v0.32.0)}
 
 OUTDIR="${HOME}/go/src"
 OPENAPI_VIOLATION_EXCEPTIONS_FILENAME="zz_generated.openapi_violation_exceptions.list"
@@ -33,26 +34,27 @@ grafana::codegen:run() {
     include_common_input_dirs=$([[ ${api_pkg} == "common" ]] && echo "true" || echo "false")
 
     kube::codegen::gen_helpers \
-      --input-pkg-root github.com/grafana/grafana/${generate_root}/apis/${api_pkg} \
-      --output-base "${OUTDIR}" \
-      --boilerplate "${SCRIPT_ROOT}/hack/boilerplate.go.txt"
+      --boilerplate "${SCRIPT_ROOT}/hack/boilerplate.go.txt" \
+      ${generate_root}/apis/${api_pkg} 
 
-    for pkg_version in $(grafana:codegen:lsdirs ./${generate_root}/apis/${api_pkg}); do
+   for pkg_version in $(grafana:codegen:lsdirs ./${generate_root}/apis/${api_pkg}); do
       grafana::codegen::gen_openapi \
-        --input-pkg-single github.com/grafana/grafana/${generate_root}/apis/${api_pkg}/${pkg_version} \
+        --input-pkg-single ${generate_root}/apis/${api_pkg}/${pkg_version} \
         --output-base "${OUTDIR}" \
         --report-filename "${OPENAPI_VIOLATION_EXCEPTIONS_FILENAME}" \
         --update-report \
         --boilerplate "${SCRIPT_ROOT}/hack/boilerplate.go.txt" \
         --include-common-input-dirs ${include_common_input_dirs}
 
-      violations_file="${OUTDIR}/github.com/grafana/grafana/${generate_root}/apis/${api_pkg}/${pkg_version}/${OPENAPI_VIOLATION_EXCEPTIONS_FILENAME}"
+      violations_file="${generate_root}/apis/${api_pkg}/${pkg_version}/${OPENAPI_VIOLATION_EXCEPTIONS_FILENAME}"
+      if [ ! -f "${violations_file}" ]; then
+          continue
+      fi
       # delete violation exceptions file, if empty
       if ! grep -q . "${violations_file}"; then
           echo "Deleting ${violations_file} since it is empty"
           rm ${violations_file}
       fi
-
       echo ""
     done
   done
@@ -67,12 +69,12 @@ grafana::codegen:run() {
   echo "-------------------------"
 
   kube::codegen::gen_client \
-      --with-watch \
-      --with-applyconfig \
-      --input-pkg-root github.com/grafana/grafana/${generate_root}/apis \
-      --output-pkg-root github.com/grafana/grafana/${generate_root}/generated \
-      --output-base "${OUTDIR}" \
-      --boilerplate "${SCRIPT_ROOT}/hack/boilerplate.go.txt"
+    --with-watch \
+    --with-applyconfig \
+    --output-dir ${generate_root}/generated \
+    --output-pkg github.com/grafana/grafana/${generate_root}/generated \
+    --boilerplate "${SCRIPT_ROOT}/hack/boilerplate.go.txt" \
+    ${generate_root}/apis
 
   echo ""
 }
@@ -83,5 +85,6 @@ grafana:codegen:lsdirs() {
 
 grafana::codegen:run pkg
 grafana::codegen:run pkg/apimachinery
+grafana::codegen:run pkg/aggregator
 
 echo "done."
