@@ -99,16 +99,14 @@ export function filterFieldConfigOverrides(
   overrides: ConfigOverrideRule[],
   condition: (value: DynamicConfigValue) => boolean
 ): ConfigOverrideRule[] {
-  return overrides
-    .map((x) => {
-      const properties = x.properties.filter(condition);
+  return overrides.map((x) => {
+    const properties = x.properties.filter(condition);
 
-      return {
-        ...x,
-        properties,
-      };
-    })
-    .filter((x) => x.properties.length > 0);
+    return {
+      ...x,
+      properties,
+    };
+  });
 }
 
 function cleanProperties(obj: object, parentPath: string, fieldConfigRegistry: FieldConfigOptionsRegistry) {
