@@ -1,10 +1,13 @@
-import { DataFrameView } from '../../dataframe';
+import { DataFrameView } from '../../dataframe/DataFrameView';
 import { toDataFrame } from '../../dataframe/processDataFrame';
-import { DataTransformContext, ScopedVars } from '../../types';
+import { ScopedVars } from '../../types/ScopedVars';
 import { FieldType } from '../../types/dataFrame';
-import { BinaryOperationID, UnaryOperationID } from '../../utils';
+import { DataTransformContext } from '../../types/transformations';
+import { BinaryOperationID } from '../../utils/binaryOperators';
 import { mockTransformationsRegistry } from '../../utils/tests/mockTransformationsRegistry';
+import { UnaryOperationID } from '../../utils/unaryOperators';
 import { ReducerID } from '../fieldReducer';
+import { FieldMatcherID } from '../matchers/ids';
 import { transformDataFrame } from '../transformDataFrame';
 
 import {
@@ -38,6 +41,15 @@ describe('calculateField transformer w/ timeseries', () => {
     mockTransformationsRegistry([calculateFieldTransformer]);
   });
 
+  beforeEach(() => {
+    seriesA.fields.forEach((f) => {
+      delete f.state;
+    });
+    seriesBC.fields.forEach((f) => {
+      delete f.state;
+    });
+  });
+
   it('will filter and alias', async () => {
     const cfg = {
       id: DataTransformerID.calculateField,
@@ -195,6 +207,201 @@ describe('calculateField transformer w/ timeseries', () => {
     });
   });
 
+  it('multiple queries + field + static number', async () => {
+    const cfg = {
+      id: DataTransformerID.calculateField,
+      options: {
+        mode: CalculateFieldMode.BinaryOperation,
+        binary: {
+          left: 'B',
+          operator: BinaryOperationID.Add,
+          right: '2',
+        },
+        replaceFields: true,
+      },
+    };
+
+    await expect(transformDataFrame([cfg], [seriesA, seriesBC])).toEmitValuesWith((received) => {
+      const data = received[0];
+      expect(data).toMatchInlineSnapshot(`
+        [
+          {
+            "fields": [
+              {
+                "config": {},
+                "name": "TheTime",
+                "state": {
+                  "displayName": "TheTime",
+                  "multipleFrames": true,
+                },
+                "type": "time",
+                "values": [
+                  1000,
+                  2000,
+                ],
+              },
+              {
+                "config": {},
+                "name": "B + 2",
+                "type": "number",
+                "values": [
+                  4,
+                  202,
+                ],
+              },
+            ],
+            "length": 2,
+          },
+        ]
+      `);
+    });
+  });
+
+  it('all numbers + static number', async () => {
+    const cfg = {
+      id: DataTransformerID.calculateField,
+      options: {
+        mode: CalculateFieldMode.BinaryOperation,
+        binary: {
+          left: { matcher: { id: FieldMatcherID.byType, options: FieldType.number } },
+          operator: BinaryOperationID.Add,
+          right: '2',
+        },
+        replaceFields: true,
+      },
+    };
+
+    await expect(transformDataFrame([cfg], [seriesBC])).toEmitValuesWith((received) => {
+      const data = received[0];
+      const filtered = data[0];
+      const rows = new DataFrameView(filtered).toArray();
+      expect(rows).toEqual([
+        {
+          'B + 2': 4,
+          'C + 2': 5,
+          TheTime: 1000,
+        },
+        {
+          'B + 2': 202,
+          'C + 2': 302,
+          TheTime: 2000,
+        },
+      ]);
+    });
+  });
+
+  it('all numbers + static number (multi-frame, avoids join)', async () => {
+    const cfg = {
+      id: DataTransformerID.calculateField,
+      options: {
+        mode: CalculateFieldMode.BinaryOperation,
+        binary: {
+          left: { matcher: { id: FieldMatcherID.byType, options: FieldType.number } },
+          operator: BinaryOperationID.Add,
+          right: '2',
+        },
+        replaceFields: true,
+      },
+    };
+
+    await expect(transformDataFrame([cfg], [seriesA, seriesBC])).toEmitValuesWith((received) => {
+      const data = received[0];
+
+      expect(data).toMatchInlineSnapshot(`
+        [
+          {
+            "fields": [
+              {
+                "config": {},
+                "name": "TheTime",
+                "type": "time",
+                "values": [
+                  1000,
+                  2000,
+                ],
+              },
+              {
+                "config": {},
+                "name": "A + 2",
+                "type": "number",
+                "values": [
+                  3,
+                  102,
+                ],
+              },
+            ],
+            "length": 2,
+          },
+          {
+            "fields": [
+              {
+                "config": {},
+                "name": "TheTime",
+                "type": "time",
+                "values": [
+                  1000,
+                  2000,
+                ],
+              },
+              {
+                "config": {},
+                "name": "B + 2",
+                "type": "number",
+                "values": [
+                  4,
+                  202,
+                ],
+              },
+              {
+                "config": {},
+                "name": "C + 2",
+                "type": "number",
+                "values": [
+                  5,
+                  302,
+                ],
+              },
+            ],
+            "length": 2,
+          },
+        ]
+      `);
+    });
+  });
+
+  it('all numbers + field number', async () => {
+    const cfg = {
+      id: DataTransformerID.calculateField,
+      options: {
+        mode: CalculateFieldMode.BinaryOperation,
+        binary: {
+          left: { matcher: { id: FieldMatcherID.byType, options: FieldType.number } },
+          operator: BinaryOperationID.Add,
+          right: 'C',
+        },
+        replaceFields: true,
+      },
+    };
+
+    await expect(transformDataFrame([cfg], [seriesBC])).toEmitValuesWith((received) => {
+      const data = received[0];
+      const filtered = data[0];
+      const rows = new DataFrameView(filtered).toArray();
+      expect(rows).toEqual([
+        {
+          'B + C': 5,
+          'C + C': 6,
+          TheTime: 1000,
+        },
+        {
+          'B + C': 500,
+          'C + C': 600,
+          TheTime: 2000,
+        },
+      ]);
+    });
+  });
+
   it('unary math', async () => {
     const unarySeries = toDataFrame({
       fields: [
@@ -377,7 +584,7 @@ describe('calculateField transformer w/ timeseries', () => {
             text: '10000',
           },
         };
-        for (const key of Object.keys(variables)) {
+        for (const key in variables) {
           if (target === `$${key}`) {
             return variables[key]!.value + '';
           }
@@ -521,6 +728,35 @@ describe('calculateField transformer w/ timeseries', () => {
     });
   });
 
+  it('calculates fixed, trailing moving average with missing values', async () => {
+    const cfg = {
+      id: DataTransformerID.calculateField,
+      options: {
+        mode: CalculateFieldMode.WindowFunctions,
+        window: {
+          windowAlignment: WindowAlignment.Trailing,
+          field: 'x',
+          windowSize: 2,
+          windowSizeMode: WindowSizeMode.Fixed,
+          reducer: ReducerID.mean,
+        },
+      },
+    };
+
+    const series = toDataFrame({
+      fields: [{ name: 'x', type: FieldType.number, values: [1, undefined, 3, 4, 5] }],
+    });
+
+    await expect(transformDataFrame([cfg], [series])).toEmitValuesWith((received) => {
+      const data = received[0][0];
+
+      //console.log(data.fields);
+
+      expect(data.fields.length).toEqual(2);
+      expect(data.fields[1].values).toEqual([1, 1, 3, 3.5, 4.5]);
+    });
+  });
+
   it('throws error when calculating moving average if window size < 1', async () => {
     const cfg = {
       id: DataTransformerID.calculateField,
