@@ -3,13 +3,15 @@ import { map } from 'rxjs/operators';
 import { guessFieldTypeForField } from '../../dataframe/processDataFrame';
 import { getFieldDisplayName } from '../../field/fieldState';
 import { DataFrame, Field, FieldType } from '../../types/dataFrame';
-import { DataTransformerInfo } from '../../types/transformations';
+import { DataTransformerInfo, TransformationApplicabilityLevels } from '../../types/transformations';
 import { ReducerID, reduceField } from '../fieldReducer';
 
 import { GroupByFieldOptions, createGroupedFields, groupValuesByKey } from './groupBy';
 import { DataTransformerID } from './ids';
+import { findMaxFields } from './utils';
 
 export const SHOW_NESTED_HEADERS_DEFAULT = true;
+const MINIMUM_FIELDS_REQUIRED = 2;
 
 enum GroupByOperationID {
   aggregate = 'aggregate',
@@ -33,7 +35,19 @@ export const groupToNestedTable: DataTransformerInfo<GroupToNestedTableTransform
     showSubframeHeaders: SHOW_NESTED_HEADERS_DEFAULT,
     fields: {},
   },
+  isApplicable: (data) => {
+    // Group to nested table needs at least two fields
+    // a field to group on and to show in the nested table
+    const maxFields = findMaxFields(data);
 
+    return maxFields >= MINIMUM_FIELDS_REQUIRED
+      ? TransformationApplicabilityLevels.Applicable
+      : TransformationApplicabilityLevels.NotApplicable;
+  },
+  isApplicableDescription: (data: DataFrame[]) => {
+    const maxFields = findMaxFields(data);
+    return `The Group to nested table transformation requires a series with at least ${MINIMUM_FIELDS_REQUIRED} fields to work. The maximum number of fields found on a series is ${maxFields}`;
+  },
   /**
    * Return a modified copy of the series. If the transform is not or should not
    * be applied, just return the input series
