@@ -2,9 +2,9 @@
  * @preserve jquery-param (c) 2015 KNOWLEDGECODE | MIT
  */
 
-import { isDateTime } from '../datetime';
-import { URLRange, RawTimeRange } from '../types';
-import { ExploreUrlState } from '../types/explore';
+import { isDateTime } from '../datetime/moment_wrapper';
+import { ExploreUrlState, URLRange } from '../types/explore';
+import { RawTimeRange } from '../types/time';
 
 /**
  * Type to represent the value of a single query variable.
