@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
-import React, { FormEvent, useCallback, useEffect, useId, useState } from 'react';
+import { FormEvent, useCallback, useEffect, useId, useState } from 'react';
+import * as React from 'react';
 
 import {
   DateTime,
@@ -21,6 +22,7 @@ import { Field } from '../../Forms/Field';
 import { Icon } from '../../Icon/Icon';
 import { Input } from '../../Input/Input';
 import { Tooltip } from '../../Tooltip/Tooltip';
+import { WeekStart } from '../WeekStartPicker';
 import { isValid } from '../utils';
 
 import TimePickerCalendar from './TimePickerCalendar';
@@ -34,6 +36,7 @@ interface Props {
   roundup?: boolean;
   isReversed?: boolean;
   onError?: (error?: string) => void;
+  weekStart?: WeekStart;
 }
 
 interface InputState {
@@ -56,6 +59,7 @@ export const TimeRangeContent = (props: Props) => {
     isReversed,
     fiscalYearStartMonth,
     onError,
+    weekStart,
   } = props;
   const [fromValue, toValue] = valueToState(value.raw.from, value.raw.to, timeZone);
   const style = useStyles2(getStyles);
@@ -223,6 +227,7 @@ export const TimeRangeContent = (props: Props) => {
         onChange={onChange}
         timeZone={timeZone}
         isReversed={isReversed}
+        weekStart={weekStart}
       />
     </div>
   );
@@ -262,6 +267,12 @@ function valueAsString(value: DateTime | string, timeZone?: TimeZone): string {
   if (isDateTime(value)) {
     return dateTimeFormat(value, { timeZone });
   }
+
+  if (value.endsWith('Z')) {
+    const dt = dateTimeParse(value, { timeZone: 'utc', format: 'YYYY-MM-DDTHH:mm:ss.SSSZ' });
+    return dateTimeFormat(dt, { timeZone });
+  }
+
   return value;
 }
 
