@@ -1,5 +1,4 @@
-import { Meta, Story } from '@storybook/react';
-import React from 'react';
+import { Meta, StoryFn } from '@storybook/react';
 import { FieldValues } from 'react-hook-form';
 
 import { Form, Input, Button, HorizontalGroup } from '@grafana/ui';
@@ -29,7 +28,7 @@ const meta: Meta = {
 
 export default meta;
 
-export const Simple: Story = (args) => {
+export const Simple: StoryFn = (args) => {
   const defaultValues: FieldValues = {
     people: [{ firstName: 'Janis', lastName: 'Joplin' }],
   };
