@@ -1,5 +1,6 @@
 import { css, cx } from '@emotion/css';
-import React, { ReactElement, useCallback, useState, useRef, useImperativeHandle, CSSProperties } from 'react';
+import { ReactElement, useCallback, useState, useRef, useImperativeHandle, CSSProperties, AriaRole } from 'react';
+import * as React from 'react';
 
 import { GrafanaTheme2, LinkTarget } from '@grafana/data';
 
@@ -29,7 +30,7 @@ export interface MenuItemProps<T = unknown> {
   /** Icon of the menu item */
   icon?: IconName;
   /** Role of the menu item */
-  role?: string;
+  role?: AriaRole;
   /** Url of the menu item */
   url?: string;
   /** Handler for the click behaviour */
@@ -51,6 +52,8 @@ export interface MenuItemProps<T = unknown> {
   shortcut?: string;
   /** Test id for e2e tests and fullstory*/
   testId?: string;
+  /* Optional component that will be shown together with other options. Does not get passed any props. */
+  component?: React.ComponentType;
 }
 
 /** @internal */
@@ -70,7 +73,7 @@ export const MenuItem = React.memo(
       disabled,
       destructive,
       childItems,
-      role = 'menuitem',
+      role,
       tabIndex = -1,
       customSubMenuContainerStyles,
       shortcut,
@@ -149,11 +152,20 @@ export const MenuItem = React.memo(
         className={itemStyle}
         rel={target === '_blank' ? 'noopener noreferrer' : undefined}
         href={url}
-        onClick={onClick}
+        onClick={(event) => {
+          if (hasSubMenu && !isSubMenuOpen) {
+            event.preventDefault();
+            event.stopPropagation();
+          }
+          onClick?.(event);
+        }}
         onMouseEnter={onMouseEnter}
         onMouseLeave={onMouseLeave}
         onKeyDown={handleKeys}
-        role={url === undefined ? role : undefined}
+        // If there's no URL, then set either the role from the props, or fallback to menuitem
+        // If there IS a URL, then use the role from props - which will result in this either being a
+        // link (default role of an anchor), or whatever the user of this component specified
+        role={!url ? role || 'menuitem' : role}
         data-role="menuitem" // used to identify menuitem in Menu.tsx
         ref={localRef}
         data-testid={testId}
@@ -191,6 +203,7 @@ export const MenuItem = React.memo(
             {description}
           </div>
         )}
+        {props.component ? <props.component /> : null}
       </ItemElement>
     );
   })
@@ -208,8 +221,10 @@ const getStyles = (theme: GrafanaTheme2) => {
       display: 'flex',
       flexDirection: 'column',
       alignItems: 'stretch',
-      padding: theme.spacing(0.5, 2),
+      justifyContent: 'center',
+      padding: theme.spacing(0.5, 1.5),
       minHeight: theme.spacing(4),
+      borderRadius: theme.shape.radius.default,
       margin: 0,
       border: 'none',
       width: '100%',
