@@ -1,10 +1,10 @@
 import { cx, css } from '@emotion/css';
-import React from 'react';
+import { forwardRef } from 'react';
 
 import { useTheme2 } from '../../themes/ThemeContext';
 import { getInputStyles } from '../Input/Input';
 
-export const IndicatorsContainer = React.forwardRef<HTMLDivElement, React.PropsWithChildren>((props, ref) => {
+export const IndicatorsContainer = forwardRef<HTMLDivElement, React.PropsWithChildren>((props, ref) => {
   const { children } = props;
   const theme = useTheme2();
   const styles = getInputStyles({ theme, invalid: false });
