@@ -8,7 +8,8 @@
   useFloating,
   useTransitionStyles,
 } from '@floating-ui/react';
-import React, { useLayoutEffect, useRef } from 'react';
+import { useLayoutEffect, useRef } from 'react';
+import * as React from 'react';
 
 import { useTheme2 } from '../../themes';
 import { getPlacement } from '../../utils/tooltipUtils';
@@ -23,6 +24,7 @@ interface Props extends Omit<React.HTMLAttributes<HTMLDivElement>, 'content'> {
   referenceElement: HTMLElement;
   wrapperClassName?: string;
   renderArrow?: boolean;
+  hidePopper?: () => void;
 }
 
 export function Popover({
@@ -33,6 +35,7 @@ export function Popover({
   wrapperClassName,
   referenceElement,
   renderArrow,
+  hidePopper,
   ...rest
 }: Props) {
   const theme = useTheme2();
@@ -94,7 +97,7 @@ export function Popover({
           {renderArrow && <FloatingArrow fill={theme.colors.border.weak} ref={arrowRef} context={context} />}
           {typeof content === 'string' && content}
           {React.isValidElement(content) && React.cloneElement(content)}
-          {typeof content === 'function' && content({})}
+          {typeof content === 'function' && content({ hidePopper })}
         </div>
       </div>
     </Portal>
