@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
-import React from 'react';
+import { useRef } from 'react';
+import * as React from 'react';
 import { CSSTransition } from 'react-transition-group';
 
 import { GrafanaTheme2 } from '@grafana/data';
@@ -7,7 +8,7 @@ import { GrafanaTheme2 } from '@grafana/data';
 import { useStyles2 } from '../../themes';
 
 type Props = {
-  children: React.ReactNode;
+  children: React.ReactElement;
   visible: boolean;
   duration?: number;
 };
@@ -15,15 +16,23 @@ type Props = {
 export function FadeTransition(props: Props) {
   const { visible, children, duration = 250 } = props;
   const styles = useStyles2(getStyles, duration);
+  const transitionRef = useRef(null);
 
   return (
-    <CSSTransition in={visible} mountOnEnter={true} unmountOnExit={true} timeout={duration} classNames={styles}>
-      {children}
+    <CSSTransition
+      in={visible}
+      mountOnEnter={true}
+      unmountOnExit={true}
+      timeout={duration}
+      classNames={styles}
+      nodeRef={transitionRef}
+    >
+      {React.cloneElement(children, { ref: transitionRef })}
     </CSSTransition>
   );
 }
 
-const getStyles = (_theme: GrafanaTheme2, duration: number) => ({
+const getStyles = (theme: GrafanaTheme2, duration: number) => ({
   enter: css({
     label: 'enter',
     opacity: 0,
@@ -31,7 +40,9 @@ const getStyles = (_theme: GrafanaTheme2, duration: number) => ({
   enterActive: css({
     label: 'enterActive',
     opacity: 1,
-    transition: `opacity ${duration}ms ease-out`,
+    [theme.transitions.handleMotion('no-preference', 'reduce')]: {
+      transition: `opacity ${duration}ms ease-out`,
+    },
   }),
   exit: css({
     label: 'exit',
@@ -40,6 +51,8 @@ const getStyles = (_theme: GrafanaTheme2, duration: number) => ({
   exitActive: css({
     label: 'exitActive',
     opacity: 0,
-    transition: `opacity ${duration}ms ease-out`,
+    [theme.transitions.handleMotion('no-preference', 'reduce')]: {
+      transition: `opacity ${duration}ms ease-out`,
+    },
   }),
 });
