@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
-import React, { useMemo } from 'react';
+import { useMemo } from 'react';
+import * as React from 'react';
 
 interface XYCanvasProps {
   top: number; // css pxls
