@@ -1,9 +1,13 @@
 package apierrors
 
 import (
+	"encoding/json"
 	"errors"
 	"net/http"
 
+	k8sErrors "k8s.io/apimachinery/pkg/api/errors"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+
 	"github.com/grafana/grafana/pkg/api/response"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/util"
@@ -31,8 +35,7 @@ func ToFolderErrorResponse(err error) response.Response {
 		return response.JSON(http.StatusNotFound, util.DynMap{"status": "not-found", "message": dashboards.ErrFolderNotFound.Error()})
 	}
 
-	if errors.Is(err, dashboards.ErrFolderSameNameExists) ||
-		errors.Is(err, dashboards.ErrFolderWithSameUIDExists) {
+	if errors.Is(err, dashboards.ErrFolderWithSameUIDExists) {
 		return response.Error(http.StatusConflict, err.Error(), nil)
 	}
 
@@ -42,3 +45,40 @@ func ToFolderErrorResponse(err error) response.Response {
 
 	return response.ErrOrFallback(http.StatusInternalServerError, "Folder API error", err)
 }
+
+func ToFolderStatusError(err error) k8sErrors.StatusError {
+	resp := ToFolderErrorResponse(err)
+	defaultErr := k8sErrors.StatusError{
+		ErrStatus: metav1.Status{
+			Message: "Folder API error",
+			Code:    http.StatusInternalServerError,
+		},
+	}
+
+	normResp, ok := resp.(*response.NormalResponse)
+	if !ok {
+		return defaultErr
+	}
+
+	var dat map[string]interface{}
+	if err := json.Unmarshal(normResp.Body(), &dat); err != nil {
+		return defaultErr
+	}
+
+	m, ok := dat["message"]
+	if !ok {
+		return defaultErr
+	}
+
+	message, ok := m.(string)
+	if !ok {
+		return defaultErr
+	}
+
+	return k8sErrors.StatusError{
+		ErrStatus: metav1.Status{
+			Message: message,
+			Code:    int32(normResp.Status()),
+		},
+	}
+}
