@@ -5,10 +5,11 @@ import (
 	"time"
 
 	"github.com/grafana/grafana/pkg/extensions"
+	"github.com/grafana/grafana/pkg/services/apiserver/standalone"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
-func getBuildstamp(opts ServerOptions) int64 {
+func getBuildstamp(opts standalone.BuildInfo) int64 {
 	buildstampInt64, err := strconv.ParseInt(opts.BuildStamp, 10, 64)
 	if err != nil || buildstampInt64 == 0 {
 		buildstampInt64 = time.Now().Unix()
@@ -16,7 +17,7 @@ func getBuildstamp(opts ServerOptions) int64 {
 	return buildstampInt64
 }
 
-func SetBuildInfo(opts ServerOptions) {
+func SetBuildInfo(opts standalone.BuildInfo) {
 	setting.BuildVersion = opts.Version
 	setting.BuildCommit = opts.Commit
 	setting.EnterpriseBuildCommit = opts.EnterpriseCommit
