@@ -4,6 +4,7 @@
 package log
 
 import (
+	"fmt"
 	"log/syslog"
 	"os"
 
@@ -55,10 +56,18 @@ func NewSyslog(sec *ini.Section, format Formatedlogger) *SysLogHandler {
 	handler.Tag = sec.Key("tag").MustString("")
 
 	if err := handler.Init(); err != nil {
+		fmt.Printf("Failed to init syslog handler. Error: %v\n", err)
 		root.Error("Failed to init syslog log handler", "error", err)
 		os.Exit(1)
 	}
 	handler.logger = gokitsyslog.NewSyslogLogger(handler.syslog, format, gokitsyslog.PrioritySelectorOption(selector))
+
+	if err := handler.Log("msg", "syslog logger initialized"); err != nil {
+		fmt.Printf("Failed to log to syslog handler. Error: %v\n", err)
+		root.Error("Failed to log to syslog log handler", "error", err)
+		os.Exit(1)
+	}
+
 	return handler
 }
 
