@@ -34,8 +34,7 @@ func TestIntegrationRedisCacheStorage(t *testing.T) {
 		b.WriteString(fmt.Sprintf(",db=%d", db))
 	}
 
-	opts := &setting.RemoteCacheOptions{Name: redisCacheType, ConnStr: b.String()}
+	opts := &setting.RemoteCacheSettings{Name: redisCacheType, ConnStr: b.String()}
 	client := createTestClient(t, opts, nil)
 	runTestsForClient(t, client)
-	runCountTestsForClient(t, opts, nil)
 }
