@@ -12,6 +12,9 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/grafana/grafana/pkg/infra/db"
+	"github.com/grafana/grafana/pkg/services/dashboards"
+	"github.com/grafana/grafana/pkg/services/folder/foldertest"
+	"github.com/grafana/grafana/pkg/services/org/orgtest"
 	"github.com/grafana/grafana/pkg/services/stats/statsimpl"
 	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/tests/testsuite"
@@ -24,8 +27,8 @@ func TestMain(m *testing.M) {
 }
 
 func TestConcurrentUsersMetrics(t *testing.T) {
-	sqlStore, cfg := db.InitTestDBwithCfg(t)
-	statsService := statsimpl.ProvideService(&setting.Cfg{}, sqlStore)
+	sqlStore, cfg := db.InitTestDBWithCfg(t)
+	statsService := statsimpl.ProvideService(&setting.Cfg{}, sqlStore, &dashboards.FakeDashboardService{}, &foldertest.FakeService{}, &orgtest.FakeOrgService{})
 	s := createService(t, cfg, sqlStore, statsService)
 
 	createConcurrentTokens(t, sqlStore)
@@ -42,8 +45,8 @@ func TestConcurrentUsersMetrics(t *testing.T) {
 }
 
 func TestConcurrentUsersStats(t *testing.T) {
-	sqlStore, cfg := db.InitTestDBwithCfg(t)
-	statsService := statsimpl.ProvideService(&setting.Cfg{}, sqlStore)
+	sqlStore, cfg := db.InitTestDBWithCfg(t)
+	statsService := statsimpl.ProvideService(&setting.Cfg{}, sqlStore, &dashboards.FakeDashboardService{}, &foldertest.FakeService{}, &orgtest.FakeOrgService{})
 	s := createService(t, cfg, sqlStore, statsService)
 
 	createConcurrentTokens(t, sqlStore)
