@@ -4,16 +4,17 @@ import (
 	"context"
 	"net/http"
 	"net/http/httptest"
-	"reflect"
 	"strings"
 	"testing"
 
 	"github.com/stretchr/testify/require"
 	"golang.org/x/oauth2"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/login/social"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
+	"github.com/grafana/grafana/pkg/services/org"
+	"github.com/grafana/grafana/pkg/services/org/orgtest"
 	"github.com/grafana/grafana/pkg/services/ssosettings"
 	ssoModels "github.com/grafana/grafana/pkg/services/ssosettings/models"
 	"github.com/grafana/grafana/pkg/services/ssosettings/ssosettingstests"
@@ -34,7 +35,6 @@ const testGHUserTeamsJSON = `[
     "permission": "admin",
     "members_url": "https://api.github.com/teams/1/members{/member}",
     "repositories_url": "https://api.github.com/teams/1/repos",
-    "parent": null,
     "members_count": 3,
     "repos_count": 10,
     "created_at": "2017-07-14T16:53:42Z",
@@ -68,7 +68,21 @@ const testGHUserTeamsJSON = `[
       "created_at": "2008-01-14T04:33:35Z",
       "updated_at": "2017-08-17T12:37:15Z",
       "type": "Organization"
-    }
+    },
+	"parent": {
+		"name": "DC",
+		"id": 99,
+		"node_id": "bm9kZTIyCg==",
+		"slug": "dc",
+		"description": "",
+		"privacy": "closed",
+		"notification_setting": "notifications_enabled",
+		"url": "https://api.github.com/organizations/github/team/2",
+		"html_url": "https://github.com/orgs/github/teams/dc",
+		"members_url": "https://api.github.com/orgs/github/members{/member}",
+		"repositories_url": "https://api.github.com/teams/2/repos",
+		"permission": "pull"
+	  }
   }
 ]`
 
@@ -129,68 +143,76 @@ func TestSocialGitHub_UserInfo(t *testing.T) {
 		settingAllowGrafanaAdmin bool
 		settingSkipOrgRoleSync   bool
 		roleAttributePath        string
-		autoAssignOrgRole        string
+		roleAttributeStrict      bool
+		orgMapping               []string
 		want                     *social.BasicUserInfo
 		wantErr                  bool
+		oAuthExtraInfo           map[string]string
 	}{
 		{
-			name:              "Basic User info",
+			name:              "should return default role if no role attribute path is set",
 			userRawJSON:       testGHUserJSON,
 			userTeamsRawJSON:  testGHUserTeamsJSON,
-			autoAssignOrgRole: "",
 			roleAttributePath: "",
 			want: &social.BasicUserInfo{
-				Id:     "1",
-				Name:   "monalisa octocat",
-				Email:  "octocat@github.com",
-				Login:  "octocat",
-				Role:   "Viewer",
-				Groups: []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{1: org.RoleViewer},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 			},
 		},
 		{
-			name:              "Admin mapping takes precedence over auto assign org role",
-			roleAttributePath: "[login==octocat] && 'Admin' || 'Viewer'",
-			userRawJSON:       testGHUserJSON,
-			autoAssignOrgRole: "Editor",
-			userTeamsRawJSON:  testGHUserTeamsJSON,
+			name:                "should fail when role attribute path is empty and role attribute strict is enabled",
+			userRawJSON:         testGHUserJSON,
+			userTeamsRawJSON:    testGHUserTeamsJSON,
+			roleAttributePath:   "",
+			roleAttributeStrict: true,
+			wantErr:             true,
+		},
+		{
+			name:                     "admin mapping takes precedence over auto assign org role",
+			roleAttributePath:        "[login==octocat] && 'Admin' || 'Viewer'",
+			userRawJSON:              testGHUserJSON,
+			settingAutoAssignOrgRole: "Editor",
+			userTeamsRawJSON:         testGHUserTeamsJSON,
 			want: &social.BasicUserInfo{
-				Id:     "1",
-				Name:   "monalisa octocat",
-				Email:  "octocat@github.com",
-				Login:  "octocat",
-				Role:   "Admin",
-				Groups: []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{1: org.RoleAdmin},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 			},
 		},
 		{
-			name:              "Editor mapping via groups",
+			name:              "should map role when role attribute path is set",
 			roleAttributePath: "contains(groups[*], '@github/justice-league') && 'Editor' || 'Viewer'",
 			userRawJSON:       testGHUserJSON,
-			autoAssignOrgRole: "Editor",
 			userTeamsRawJSON:  testGHUserTeamsJSON,
 			want: &social.BasicUserInfo{
-				Id:     "1",
-				Name:   "monalisa octocat",
-				Email:  "octocat@github.com",
-				Login:  "octocat",
-				Role:   "Editor",
-				Groups: []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{1: org.RoleEditor},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 			},
 		},
 		{
-			name:                   "Should be empty role if setting skipOrgRoleSync is set to true",
+			name:                   "should return empty role when skip org role sync is true",
 			roleAttributePath:      "contains(groups[*], '@github/justice-league') && 'Editor' || 'Viewer'",
 			settingSkipOrgRoleSync: true,
 			userRawJSON:            testGHUserJSON,
 			userTeamsRawJSON:       testGHUserTeamsJSON,
 			want: &social.BasicUserInfo{
-				Id:     "1",
-				Name:   "monalisa octocat",
-				Email:  "octocat@github.com",
-				Login:  "octocat",
-				Role:   "",
-				Groups: []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: nil,
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 			},
 		},
 		{
@@ -205,26 +227,89 @@ func TestSocialGitHub_UserInfo(t *testing.T) {
 				Name:           "monalisa octocat",
 				Email:          "octocat@github.com",
 				Login:          "octocat",
-				Role:           "",
+				OrgRoles:       nil,
 				Groups:         []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 				IsGrafanaAdmin: boolPointer,
 			},
 		},
 		{
-			name:              "fallback to default org role",
-			roleAttributePath: "",
-			userRawJSON:       testGHUserJSON,
-			autoAssignOrgRole: "Editor",
-			userTeamsRawJSON:  testGHUserTeamsJSON,
+			name:                     "should fallback to default org role when role attribute path is empty and auto assign org role is set",
+			roleAttributePath:        "",
+			userRawJSON:              testGHUserJSON,
+			settingAutoAssignOrgRole: "Editor",
+			userTeamsRawJSON:         testGHUserTeamsJSON,
 			want: &social.BasicUserInfo{
-				Id:     "1",
-				Name:   "monalisa octocat",
-				Email:  "octocat@github.com",
-				Login:  "octocat",
-				Role:   "Editor",
-				Groups: []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{1: org.RoleEditor},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
 			},
 		},
+		{
+			// see: https://github.com/grafana/grafana/issues/85916
+			name:                     "should check parent team id for team membership",
+			roleAttributePath:        "",
+			userRawJSON:              testGHUserJSON,
+			settingAutoAssignOrgRole: "Editor",
+			userTeamsRawJSON:         testGHUserTeamsJSON,
+			oAuthExtraInfo: map[string]string{
+				"team_ids": "99",
+			},
+			want: &social.BasicUserInfo{
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{1: org.RoleEditor},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+			},
+		},
+		{
+			name:             "should map role when only org mapping is set",
+			orgMapping:       []string{"@github/justice-league:Org4:Editor", "*:Org5:Viewer"},
+			userRawJSON:      testGHUserJSON,
+			userTeamsRawJSON: testGHUserTeamsJSON,
+			want: &social.BasicUserInfo{
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{4: "Editor", 5: "Viewer"},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+			},
+		},
+		{
+			name:                "should map role when only org mapping is set and role attribute strict is enabled",
+			orgMapping:          []string{"@github/justice-league:Org4:Editor", "*:Org5:Viewer"},
+			roleAttributeStrict: true,
+			userRawJSON:         testGHUserJSON,
+			userTeamsRawJSON:    testGHUserTeamsJSON,
+			want: &social.BasicUserInfo{
+				Id:       "1",
+				Name:     "monalisa octocat",
+				Email:    "octocat@github.com",
+				Login:    "octocat",
+				OrgRoles: map[int64]org.RoleType{4: "Editor", 5: "Viewer"},
+				Groups:   []string{"https://github.com/orgs/github/teams/justice-league", "@github/justice-league"},
+			},
+		},
+		{
+			name:                "should return error when neither role attribute path nor org mapping evaluates to a role and role attribute strict is enabled",
+			orgMapping:          []string{"@github/avengers:Org4:Editor"},
+			roleAttributeStrict: true,
+			userRawJSON:         testGHUserJSON,
+			userTeamsRawJSON:    testGHUserTeamsJSON,
+			wantErr:             true,
+		},
+		{
+			name:                "should return error when neither role attribute path nor org mapping is set and role attribute strict is enabled",
+			roleAttributeStrict: true,
+			userRawJSON:         testGHUserJSON,
+			userTeamsRawJSON:    testGHUserTeamsJSON,
+			wantErr:             true,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -245,18 +330,26 @@ func TestSocialGitHub_UserInfo(t *testing.T) {
 			}))
 			defer server.Close()
 
+			cfg := &setting.Cfg{
+				AutoAssignOrgRole: "Viewer", // default role
+			}
+
+			if tt.settingAutoAssignOrgRole != "" {
+				cfg.AutoAssignOrgRole = tt.settingAutoAssignOrgRole
+			}
+
 			s := NewGitHubProvider(
 				&social.OAuthInfo{
-					ApiUrl:            server.URL + "/user",
-					RoleAttributePath: tt.roleAttributePath,
-					SkipOrgRoleSync:   tt.settingSkipOrgRoleSync,
-					Extra: map[string]string{
-						"allowed_organizations": "",
-						"team_ids":              "",
-					},
-				}, &setting.Cfg{
-					AutoAssignOrgRole: tt.autoAssignOrgRole,
-				}, &ssosettingstests.MockService{},
+					ApiUrl:              server.URL + "/user",
+					RoleAttributePath:   tt.roleAttributePath,
+					RoleAttributeStrict: tt.roleAttributeStrict,
+					OrgMapping:          tt.orgMapping,
+					SkipOrgRoleSync:     tt.settingSkipOrgRoleSync,
+					Extra:               tt.oAuthExtraInfo,
+				}, cfg,
+				ProvideOrgRoleMapper(cfg,
+					&orgtest.FakeOrgService{ExpectedOrgs: []*org.OrgDTO{{ID: 4, Name: "Org4"}, {ID: 5, Name: "Org5"}}}),
+				&ssosettingstests.MockService{},
 				featuremgmt.WithFeatures())
 
 			token := &oauth2.Token{
@@ -264,13 +357,12 @@ func TestSocialGitHub_UserInfo(t *testing.T) {
 			}
 
 			got, err := s.UserInfo(context.Background(), server.Client(), token)
-			if (err != nil) != tt.wantErr {
-				t.Errorf("UserInfo() error = %v, wantErr %v", err, tt.wantErr)
+			if tt.wantErr {
+				require.Error(t, err)
 				return
 			}
-			if !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("UserInfo() got = %v, want %v", got, tt.want)
-			}
+
+			require.EqualValues(t, tt.want, got)
 		})
 	}
 }
@@ -338,7 +430,7 @@ func TestSocialGitHub_InitializeExtraFields(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			s := NewGitHubProvider(tc.settings, &setting.Cfg{}, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
+			s := NewGitHubProvider(tc.settings, &setting.Cfg{}, nil, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
 
 			require.Equal(t, tc.want.teamIds, s.teamIds)
 			require.Equal(t, tc.want.allowedOrganizations, s.allowedOrganizations)
@@ -465,13 +557,13 @@ func TestSocialGitHub_Validate(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			s := NewGitHubProvider(&social.OAuthInfo{}, &setting.Cfg{}, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
+			s := NewGitHubProvider(&social.OAuthInfo{}, &setting.Cfg{}, nil, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
 
 			if tc.requester == nil {
 				tc.requester = &user.SignedInUser{IsGrafanaAdmin: false}
 			}
 
-			err := s.Validate(context.Background(), tc.settings, tc.requester)
+			err := s.Validate(context.Background(), tc.settings, ssoModels.SSOSettings{}, tc.requester)
 			if tc.wantErr != nil {
 				require.ErrorIs(t, err, tc.wantErr)
 				return
@@ -546,7 +638,7 @@ func TestSocialGitHub_Reload(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			s := NewGitHubProvider(tc.info, &setting.Cfg{}, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
+			s := NewGitHubProvider(tc.info, &setting.Cfg{}, nil, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
 
 			err := s.Reload(context.Background(), tc.settings)
 			if tc.expectError {
@@ -605,7 +697,7 @@ func TestGitHub_Reload_ExtraFields(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			s := NewGitHubProvider(tc.info, setting.NewCfg(), &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
+			s := NewGitHubProvider(tc.info, setting.NewCfg(), nil, &ssosettingstests.MockService{}, featuremgmt.WithFeatures())
 
 			err := s.Reload(context.Background(), tc.settings)
 			require.NoError(t, err)
