@@ -1,7 +1,14 @@
 package api
 
 import (
+	"context"
+	"errors"
+	"fmt"
 	"net/http"
+	"strconv"
+
+	"github.com/grafana/authlib/claims"
+	"go.opentelemetry.io/otel"
 
 	"github.com/grafana/grafana/pkg/api/response"
 	"github.com/grafana/grafana/pkg/api/routing"
@@ -10,13 +17,17 @@ import (
 	ac "github.com/grafana/grafana/pkg/services/accesscontrol"
 	contextmodel "github.com/grafana/grafana/pkg/services/contexthandler/model"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
+	"github.com/grafana/grafana/pkg/services/user"
 )
 
+var tracer = otel.Tracer("github.com/grafana/grafana/pkg/services/accesscontrol/api")
+
 func NewAccessControlAPI(router routing.RouteRegister, accesscontrol ac.AccessControl, service ac.Service,
-	features featuremgmt.FeatureToggles) *AccessControlAPI {
+	userSvc user.Service, features featuremgmt.FeatureToggles) *AccessControlAPI {
 	return &AccessControlAPI{
 		RouteRegister: router,
 		Service:       service,
+		userSvc:       userSvc,
 		AccessControl: accesscontrol,
 		features:      features,
 	}
@@ -26,6 +37,7 @@ type AccessControlAPI struct {
 	Service       ac.Service
 	AccessControl ac.AccessControl
 	RouteRegister routing.RouteRegister
+	userSvc       user.Service
 	features      featuremgmt.FeatureToggles
 }
 
@@ -43,9 +55,11 @@ func (api *AccessControlAPI) RegisterAPIEndpoints() {
 
 // GET /api/access-control/user/actions
 func (api *AccessControlAPI) getUserActions(c *contextmodel.ReqContext) response.Response {
+	ctx, span := tracer.Start(c.Req.Context(), "accesscontrol.api.getUserActions")
+	defer span.End()
+
 	reloadCache := c.QueryBool("reloadcache")
-	permissions, err := api.Service.GetUserPermissions(c.Req.Context(),
-		c.SignedInUser, ac.Options{ReloadCache: reloadCache})
+	permissions, err := api.Service.GetUserPermissions(ctx, c.SignedInUser, ac.Options{ReloadCache: reloadCache})
 	if err != nil {
 		return response.JSON(http.StatusInternalServerError, err)
 	}
@@ -55,35 +69,54 @@ func (api *AccessControlAPI) getUserActions(c *contextmodel.ReqContext) response
 
 // GET /api/access-control/user/permissions
 func (api *AccessControlAPI) getUserPermissions(c *contextmodel.ReqContext) response.Response {
+	ctx, span := tracer.Start(c.Req.Context(), "accesscontrol.api.getUserPermissions")
+	defer span.End()
+
 	reloadCache := c.QueryBool("reloadcache")
-	permissions, err := api.Service.GetUserPermissions(c.Req.Context(),
-		c.SignedInUser, ac.Options{ReloadCache: reloadCache})
+	permissions, err := api.Service.GetUserPermissions(ctx, c.SignedInUser, ac.Options{ReloadCache: reloadCache})
 	if err != nil {
 		return response.JSON(http.StatusInternalServerError, err)
 	}
 
-	return response.JSON(http.StatusOK, ac.GroupScopesByAction(permissions))
+	return response.JSON(http.StatusOK, ac.GroupScopesByActionContext(ctx, permissions))
 }
 
 // GET /api/access-control/users/permissions/search
 func (api *AccessControlAPI) searchUsersPermissions(c *contextmodel.ReqContext) response.Response {
+	ctx, span := tracer.Start(c.Req.Context(), "accesscontrol.api.searchUsersPermissions")
+	defer span.End()
+
 	searchOptions := ac.SearchOptions{
 		ActionPrefix: c.Query("actionPrefix"),
 		Action:       c.Query("action"),
 		Scope:        c.Query("scope"),
-		NamespacedID: c.Query("namespacedId"),
+	}
+
+	// namespacedId is the typed identifier of an identity
+	// it is specified using user/service account IDs or UIDs (ex: user:3, service-account:4, user:adisufjf93e9sd)
+	if typedID := c.Query("namespacedId"); typedID != "" {
+		userID, err := api.ComputeUserID(ctx, c.Query("namespacedId"))
+		if err != nil {
+			if errors.Is(err, user.ErrUserNotFound) {
+				return response.JSON(http.StatusBadRequest, err.Error())
+			}
+			return response.JSON(http.StatusInternalServerError, err.Error())
+		}
+
+		searchOptions.UserID = userID
 	}
 
 	// Validate inputs
 	if searchOptions.ActionPrefix != "" && searchOptions.Action != "" {
 		return response.JSON(http.StatusBadRequest, "'action' and 'actionPrefix' are mutually exclusive")
 	}
-	if searchOptions.NamespacedID == "" && searchOptions.ActionPrefix == "" && searchOptions.Action == "" {
+
+	if searchOptions.UserID <= 0 && searchOptions.ActionPrefix == "" && searchOptions.Action == "" {
 		return response.JSON(http.StatusBadRequest, "at least one search option must be provided")
 	}
 
 	// Compute metadata
-	permissions, err := api.Service.SearchUsersPermissions(c.Req.Context(), c.SignedInUser, searchOptions)
+	permissions, err := api.Service.SearchUsersPermissions(ctx, c.SignedInUser, searchOptions)
 	if err != nil {
 		return response.Error(http.StatusInternalServerError, "could not get org user permissions", err)
 	}
@@ -95,3 +128,30 @@ func (api *AccessControlAPI) searchUsersPermissions(c *contextmodel.ReqContext)
 
 	return response.JSON(http.StatusOK, permsByAction)
 }
+
+func (api *AccessControlAPI) ComputeUserID(ctx context.Context, typedID string) (int64, error) {
+	if typedID == "" {
+		return -1, nil
+	}
+
+	typ, idStr, err := claims.ParseTypeID(typedID)
+	if err != nil {
+		return 0, err
+	}
+
+	if !claims.IsIdentityType(typ, claims.TypeUser, claims.TypeServiceAccount) {
+		return 0, fmt.Errorf("invalid type: %s", typ)
+	}
+
+	id, err := strconv.ParseInt(idStr, 10, 64)
+	if err == nil {
+		return id, nil
+	}
+
+	user, err := api.userSvc.GetByUID(ctx, &user.GetUserByUIDQuery{UID: idStr})
+	if err != nil {
+		return 0, err
+	}
+
+	return user.ID, nil
+}
