@@ -14,9 +14,11 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/authlib/claims"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/login/social"
 	"github.com/grafana/grafana/pkg/login/social/socialtest"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
+	"github.com/grafana/grafana/pkg/services/auth"
 	"github.com/grafana/grafana/pkg/services/authn"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/login"
@@ -70,10 +72,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return error when state from ipd does not match stored state",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-other-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-other-state"),
+				},
 			},
 			oauthCfg:         &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			addStateCookie:   true,
@@ -82,10 +85,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return error when pkce is configured but the cookie is not present",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-state"),
+				},
 			},
 			oauthCfg:         &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			addStateCookie:   true,
@@ -94,10 +98,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return error when email is empty",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-state"),
+				},
 			},
 			oauthCfg:         &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			addStateCookie:   true,
@@ -109,10 +114,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return error when email is not allowed",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-state"),
+				},
 			},
 			oauthCfg:         &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			addStateCookie:   true,
@@ -143,10 +149,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return identity for valid request",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-state"),
+				},
 			},
 			oauthCfg:         &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			addStateCookie:   true,
@@ -181,10 +188,11 @@ func TestOAuth_Authenticate(t *testing.T) {
 		},
 		{
 			desc: "should return identity for valid request - and lookup user by email",
-			req: &authn.Request{HTTPRequest: &http.Request{
-				Header: map[string][]string{},
-				URL:    mustParseURL("http://grafana.com/?state=some-state"),
-			},
+			req: &authn.Request{
+				HTTPRequest: &http.Request{
+					Header: map[string][]string{},
+					URL:    mustParseURL("http://grafana.com/?state=some-state"),
+				},
 			},
 			oauthCfg:              &social.OAuthInfo{UsePKCE: true, Enabled: true},
 			allowInsecureTakeover: true,
@@ -308,7 +316,6 @@ func TestOAuth_Authenticate(t *testing.T) {
 
 				assert.EqualValues(t, tt.expectedIdentity.ClientParams.LookUpParams.Email, identity.ClientParams.LookUpParams.Email)
 				assert.EqualValues(t, tt.expectedIdentity.ClientParams.LookUpParams.Login, identity.ClientParams.LookUpParams.Login)
-				assert.EqualValues(t, tt.expectedIdentity.ClientParams.LookUpParams.UserID, identity.ClientParams.LookUpParams.UserID)
 			} else {
 				assert.Nil(t, tt.expectedIdentity)
 			}
@@ -354,9 +361,7 @@ func TestOAuth_RedirectURL(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.desc, func(t *testing.T) {
-			var (
-				authCodeUrlCalled = false
-			)
+			authCodeUrlCalled := false
 
 			fakeSocialSvc := &socialtest.FakeSocialService{
 				ExpectedAuthInfoProvider: tt.oauthCfg,
@@ -465,7 +470,7 @@ func TestOAuth_Logout(t *testing.T) {
 			)
 
 			mockService := &oauthtokentest.MockOauthTokenService{
-				GetCurrentOauthTokenFunc: func(_ context.Context, _ identity.Requester) *oauth2.Token {
+				GetCurrentOauthTokenFunc: func(_ context.Context, _ identity.Requester, _ *auth.UserToken) *oauth2.Token {
 					getTokenCalled = true
 					token := &oauth2.Token{
 						AccessToken: "some.access.token",
@@ -475,7 +480,7 @@ func TestOAuth_Logout(t *testing.T) {
 						"id_token": "some.id.token",
 					})
 				},
-				InvalidateOAuthTokensFunc: func(_ context.Context, _ *login.UserAuth) error {
+				InvalidateOAuthTokensFunc: func(_ context.Context, _ identity.Requester, _ *auth.UserToken) error {
 					invalidateTokenCalled = true
 					return nil
 				},
@@ -486,7 +491,7 @@ func TestOAuth_Logout(t *testing.T) {
 			}
 			c := ProvideOAuth(authn.ClientWithPrefix("azuread"), tt.cfg, mockService, fakeSocialSvc, &setting.OSSImpl{Cfg: tt.cfg}, featuremgmt.WithFeatures())
 
-			redirect, ok := c.Logout(context.Background(), &authn.Identity{}, &login.UserAuth{})
+			redirect, ok := c.Logout(context.Background(), &authn.Identity{ID: "1", Type: claims.TypeUser}, nil)
 
 			assert.Equal(t, tt.expectedOK, ok)
 			if tt.expectedOK {
@@ -507,6 +512,49 @@ func TestGenPKCECodeVerifier(t *testing.T) {
 	assert.Len(t, verifier, 128)
 }
 
+func TestIsEnabled(t *testing.T) {
+	type testCase struct {
+		desc     string
+		oauthCfg *social.OAuthInfo
+		expected bool
+	}
+
+	tests := []testCase{
+		{
+			desc:     "should return false when client is not enabled",
+			oauthCfg: &social.OAuthInfo{Enabled: false},
+			expected: false,
+		},
+		{
+			desc:     "should return false when client doesnt exists",
+			oauthCfg: nil,
+			expected: false,
+		},
+		{
+			desc:     "should return true when client is enabled",
+			oauthCfg: &social.OAuthInfo{Enabled: true},
+			expected: true,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.desc, func(t *testing.T) {
+			fakeSocialSvc := &socialtest.FakeSocialService{
+				ExpectedAuthInfoProvider: tt.oauthCfg,
+			}
+			cfg := setting.NewCfg()
+			c := ProvideOAuth(
+				social.GitHubProviderName,
+				cfg,
+				nil,
+				fakeSocialSvc,
+				&setting.OSSImpl{Cfg: cfg},
+				featuremgmt.WithFeatures())
+			assert.Equal(t, tt.expected, c.IsEnabled())
+		})
+	}
+}
+
 type mockConnector struct {
 	AuthCodeURLFunc func(state string, opts ...oauth2.AuthCodeOption) string
 	social.SocialConnector
