@@ -8,7 +8,9 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/authlib/claims"
 	"github.com/grafana/grafana/pkg/api/routing"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/infra/tracing"
 	"github.com/grafana/grafana/pkg/services/authn"
 	"github.com/grafana/grafana/pkg/services/authn/authntest"
@@ -26,8 +28,8 @@ func TestContextHandler(t *testing.T) {
 		handler := contexthandler.ProvideService(
 			setting.NewCfg(),
 			tracing.InitializeTracerForTest(),
-			featuremgmt.WithFeatures(),
 			&authntest.FakeService{ExpectedErr: errors.New("some error")},
+			featuremgmt.WithFeatures(),
 		)
 
 		server := webtest.NewServer(t, routing.NewRouteRegister())
@@ -44,20 +46,24 @@ func TestContextHandler(t *testing.T) {
 	})
 
 	t.Run("should set identity on successful authentication", func(t *testing.T) {
-		identity := &authn.Identity{ID: authn.NamespacedID(authn.NamespaceUser, 1), OrgID: 1}
+		id := &authn.Identity{ID: "1", Type: claims.TypeUser, OrgID: 1}
 		handler := contexthandler.ProvideService(
 			setting.NewCfg(),
 			tracing.InitializeTracerForTest(),
+			&authntest.FakeService{ExpectedIdentity: id},
 			featuremgmt.WithFeatures(),
-			&authntest.FakeService{ExpectedIdentity: identity},
 		)
 
 		server := webtest.NewServer(t, routing.NewRouteRegister())
 		server.Mux.Use(handler.Middleware)
 		server.Mux.Get("/api/handler", func(c *contextmodel.ReqContext) {
 			require.True(t, c.IsSignedIn)
-			require.EqualValues(t, identity.SignedInUser(), c.SignedInUser)
+			require.EqualValues(t, id.SignedInUser(), c.SignedInUser)
 			require.NoError(t, c.LookupTokenErr)
+
+			requester, err := identity.GetRequester(c.Req.Context())
+			require.NoError(t, err)
+			require.Equal(t, id, requester)
 		})
 
 		res, err := server.Send(server.NewGetRequest("/api/handler"))
@@ -66,12 +72,12 @@ func TestContextHandler(t *testing.T) {
 	})
 
 	t.Run("should not set IsSignedIn on anonymous identity", func(t *testing.T) {
-		identity := &authn.Identity{ID: authn.AnonymousNamespaceID, OrgID: 1}
+		identity := &authn.Identity{ID: "0", Type: claims.TypeAnonymous, OrgID: 1}
 		handler := contexthandler.ProvideService(
 			setting.NewCfg(),
 			tracing.InitializeTracerForTest(),
-			featuremgmt.WithFeatures(),
 			&authntest.FakeService{ExpectedIdentity: identity},
+			featuremgmt.WithFeatures(),
 		)
 
 		server := webtest.NewServer(t, routing.NewRouteRegister())
@@ -92,8 +98,8 @@ func TestContextHandler(t *testing.T) {
 		handler := contexthandler.ProvideService(
 			setting.NewCfg(),
 			tracing.InitializeTracerForTest(),
-			featuremgmt.WithFeatures(),
 			&authntest.FakeService{ExpectedIdentity: identity},
+			featuremgmt.WithFeatures(),
 		)
 
 		server := webtest.NewServer(t, routing.NewRouteRegister())
@@ -123,8 +129,8 @@ func TestContextHandler(t *testing.T) {
 		handler := contexthandler.ProvideService(
 			cfg,
 			tracing.InitializeTracerForTest(),
-			featuremgmt.WithFeatures(),
 			&authntest.FakeService{ExpectedIdentity: &authn.Identity{}},
+			featuremgmt.WithFeatures(),
 		)
 
 		server := webtest.NewServer(t, routing.NewRouteRegister())
@@ -146,11 +152,14 @@ func TestContextHandler(t *testing.T) {
 
 	t.Run("id response headers", func(t *testing.T) {
 		run := func(cfg *setting.Cfg, id string) *http.Response {
+			typ, i, err := claims.ParseTypeID(id)
+			require.NoError(t, err)
+
 			handler := contexthandler.ProvideService(
 				cfg,
 				tracing.InitializeTracerForTest(),
+				&authntest.FakeService{ExpectedIdentity: &authn.Identity{ID: i, Type: typ}},
 				featuremgmt.WithFeatures(),
-				&authntest.FakeService{ExpectedIdentity: &authn.Identity{ID: id}},
 			)
 
 			server := webtest.NewServer(t, routing.NewRouteRegister())
