@@ -3,13 +3,9 @@ package model
 import (
 	"encoding/json"
 	"errors"
-	"fmt"
 	"time"
 
-	"github.com/grafana/grafana/pkg/components/simplejson"
-	"github.com/grafana/grafana/pkg/kinds"
 	"github.com/grafana/grafana/pkg/kinds/librarypanel"
-	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 type LibraryConnectionKind int
@@ -20,9 +16,11 @@ const (
 
 // LibraryElement is the model for library element definitions.
 type LibraryElement struct {
-	ID          int64  `xorm:"pk autoincr 'id'"`
-	OrgID       int64  `xorm:"org_id"`
+	ID    int64 `xorm:"pk autoincr 'id'"`
+	OrgID int64 `xorm:"org_id"`
+	// Deprecated: use FolderUID instead
 	FolderID    int64  `xorm:"folder_id"`
+	FolderUID   string `xorm:"folder_uid"`
 	UID         string `xorm:"uid"`
 	Name        string
 	Kind        int64
@@ -40,9 +38,11 @@ type LibraryElement struct {
 
 // LibraryElementWithMeta is the model used to retrieve entities with additional meta information.
 type LibraryElementWithMeta struct {
-	ID          int64  `xorm:"pk autoincr 'id'"`
-	OrgID       int64  `xorm:"org_id"`
+	ID    int64 `xorm:"pk autoincr 'id'"`
+	OrgID int64 `xorm:"org_id"`
+	// Deprecated: use FolderUID instead
 	FolderID    int64  `xorm:"folder_id"`
+	FolderUID   string `xorm:"folder_uid"`
 	UID         string `xorm:"uid"`
 	Name        string
 	Kind        int64
@@ -55,7 +55,6 @@ type LibraryElementWithMeta struct {
 	Updated time.Time
 
 	FolderName          string
-	FolderUID           string `xorm:"folder_uid"`
 	ConnectedDashboards int64
 	CreatedBy           int64
 	UpdatedBy           int64
@@ -67,8 +66,9 @@ type LibraryElementWithMeta struct {
 
 // LibraryElementDTO is the frontend DTO for entities.
 type LibraryElementDTO struct {
-	ID            int64                 `json:"id"`
-	OrgID         int64                 `json:"orgId"`
+	ID    int64 `json:"id"`
+	OrgID int64 `json:"orgId"`
+	// Deprecated: use FolderUID instead
 	FolderID      int64                 `json:"folderId"`
 	FolderUID     string                `json:"folderUid"`
 	UID           string                `json:"uid"`
@@ -82,32 +82,6 @@ type LibraryElementDTO struct {
 	SchemaVersion int64                 `json:"schemaVersion,omitempty"`
 }
 
-func (dto *LibraryElementDTO) ToResource() kinds.GrafanaResource[simplejson.Json, simplejson.Json] {
-	body := &simplejson.Json{}
-	_ = body.FromDB(dto.Model)
-	parent := librarypanel.NewK8sResource(dto.UID, nil)
-	res := kinds.GrafanaResource[simplejson.Json, simplejson.Json]{
-		Kind:       parent.Kind,
-		APIVersion: parent.APIVersion,
-		Metadata: kinds.GrafanaResourceMetadata{
-			Name:              dto.UID,
-			Annotations:       make(map[string]string),
-			Labels:            make(map[string]string),
-			ResourceVersion:   fmt.Sprintf("%d", dto.Version),
-			CreationTimestamp: v1.NewTime(dto.Meta.Created),
-		},
-		Spec: body,
-	}
-
-	if dto.FolderUID != "" {
-		res.Metadata.SetFolder(dto.FolderUID)
-	}
-	res.Metadata.SetCreatedBy(fmt.Sprintf("user:%d", dto.Meta.CreatedBy.Id))
-	res.Metadata.SetUpdatedBy(fmt.Sprintf("user:%d", dto.Meta.UpdatedBy.Id))
-	res.Metadata.SetUpdatedTimestamp(&dto.Meta.Updated)
-	return res
-}
-
 // LibraryElementSearchResult is the search result for entities.
 type LibraryElementSearchResult struct {
 	TotalCount int64               `json:"totalCount"`
@@ -190,6 +164,8 @@ var (
 // swagger:model
 type CreateLibraryElementCommand struct {
 	// ID of the folder where the library element is stored.
+	//
+	// Deprecated: use FolderUID instead
 	FolderID int64 `json:"folderId"`
 	// UID of the folder where the library element is stored.
 	FolderUID *string `json:"folderUid"`
@@ -211,6 +187,8 @@ type CreateLibraryElementCommand struct {
 // PatchLibraryElementCommand is the command for patching a LibraryElement
 type PatchLibraryElementCommand struct {
 	// ID of the folder where the library element is stored.
+	//
+	// Deprecated: use FolderUID instead
 	FolderID int64 `json:"folderId" binding:"Default(-1)"`
 	// UID of the folder where the library element is stored.
 	FolderUID *string `json:"folderUid"`
@@ -233,19 +211,21 @@ type PatchLibraryElementCommand struct {
 // GetLibraryElementCommand is the command for getting a library element.
 type GetLibraryElementCommand struct {
 	FolderName string
-	FolderID   int64
-	UID        string
+	// Deprecated: use FolderUID instead
+	FolderID int64
+	UID      string
 }
 
 // SearchLibraryElementsQuery is the query used for searching for Elements
 type SearchLibraryElementsQuery struct {
-	PerPage          int
-	Page             int
-	SearchString     string
-	SortDirection    string
-	Kind             int
-	TypeFilter       string
-	ExcludeUID       string
+	PerPage       int
+	Page          int
+	SearchString  string
+	SortDirection string
+	Kind          int
+	TypeFilter    string
+	ExcludeUID    string
+	// Deprecated: use FolderFilterUIDs instead
 	FolderFilter     string
 	FolderFilterUIDs string
 }
