@@ -10,13 +10,16 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/expr"
 	"github.com/grafana/grafana/pkg/services/accesscontrol"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
+	"github.com/grafana/grafana/pkg/services/accesscontrol/acimpl"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/datasources"
+	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/folder"
 	"github.com/grafana/grafana/pkg/services/ngalert/models"
+	"github.com/grafana/grafana/pkg/services/ngalert/notifier/legacy_storage"
 	"github.com/grafana/grafana/pkg/services/ngalert/store"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/util"
@@ -75,6 +78,22 @@ func getDatasourceScopesForRules(rules models.RulesGroup) []string {
 	return result
 }
 
+func getReceiverScopesForRules(rules models.RulesGroup) []string {
+	scopesMap := map[string]struct{}{}
+	var result []string
+	for _, rule := range rules {
+		for _, ns := range rule.NotificationSettings {
+			scope := ScopeReceiversProvider.GetResourceScopeUID(legacy_storage.NameToUid(ns.Receiver))
+			if _, ok := scopesMap[scope]; ok {
+				continue
+			}
+			result = append(result, scope)
+			scopesMap[scope] = struct{}{}
+		}
+	}
+	return result
+}
+
 func mapUpdates(updates []store.RuleDelta, mapFunc func(store.RuleDelta) *models.AlertRule) models.RulesGroup {
 	result := make(models.RulesGroup, 0, len(updates))
 	for _, update := range updates {
@@ -92,6 +111,8 @@ func createUserWithPermissions(permissions map[string][]string) identity.Request
 func TestAuthorizeRuleChanges(t *testing.T) {
 	groupKey := models.GenerateGroupKey(rand.Int63())
 	namespaceIdScope := dashboards.ScopeFoldersProvider.GetResourceScopeUID(groupKey.NamespaceUID)
+	gen := models.RuleGen
+	genWithGroupKey := gen.With(gen.WithGroupKey(groupKey))
 
 	testCases := []struct {
 		name        string
@@ -103,18 +124,12 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 			changes: func() *store.GroupDelta {
 				return &store.GroupDelta{
 					GroupKey: groupKey,
-					New:      models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey))),
+					New:      genWithGroupKey.GenerateManyRef(1, 5),
 					Update:   nil,
 					Delete:   nil,
 				}
 			},
 			permissions: func(c *store.GroupDelta) map[string][]string {
-				var scopes []string
-				for _, rule := range c.New {
-					for _, query := range rule.Data {
-						scopes = append(scopes, datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID))
-					}
-				}
 				return map[string][]string{
 					ruleCreate: {
 						namespaceIdScope,
@@ -125,15 +140,16 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 					dashboards.ActionFoldersRead: {
 						namespaceIdScope,
 					},
-					datasources.ActionQuery: scopes,
+					datasources.ActionQuery:                   getDatasourceScopesForRules(c.New),
+					accesscontrol.ActionAlertingReceiversRead: getReceiverScopesForRules(c.New),
 				}
 			},
 		},
 		{
 			name: "if there are rules to delete it should check delete action and query for datasource",
 			changes: func() *store.GroupDelta {
-				rules := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
-				rules2 := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
+				rules := genWithGroupKey.GenerateManyRef(1, 5)
+				rules2 := genWithGroupKey.GenerateManyRef(1, 5)
 				return &store.GroupDelta{
 					GroupKey: groupKey,
 					AffectedGroups: map[models.AlertRuleGroupKey]models.RulesGroup{
@@ -155,15 +171,15 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 					ruleDelete: {
 						namespaceIdScope,
 					},
-					datasources.ActionQuery: getDatasourceScopesForRules(c.AffectedGroups[c.GroupKey]),
+					datasources.ActionQuery: getDatasourceScopesForRules(c.Delete),
 				}
 			},
 		},
 		{
 			name: "if there are rules to update within the same namespace it should check update action and access to datasource",
 			changes: func() *store.GroupDelta {
-				rules1 := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
-				rules := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
+				rules1 := genWithGroupKey.GenerateManyRef(1, 5)
+				rules := genWithGroupKey.GenerateManyRef(1, 5)
 				updates := make([]store.RuleDelta, 0, len(rules))
 
 				for _, rule := range rules {
@@ -187,9 +203,9 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				}
 			},
 			permissions: func(c *store.GroupDelta) map[string][]string {
-				scopes := getDatasourceScopesForRules(append(c.AffectedGroups[c.GroupKey], mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
+				scopes := getDatasourceScopesForRules(mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
 					return update.New
-				})...))
+				}))
 				return map[string][]string{
 					ruleRead: {
 						namespaceIdScope,
@@ -207,18 +223,14 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 		{
 			name: "if there are rules that are moved between namespaces it should check delete+add action and access to group where rules come from",
 			changes: func() *store.GroupDelta {
-				rules1 := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
-				rules := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
+				rules1 := genWithGroupKey.GenerateManyRef(1, 5)
+				rules := genWithGroupKey.GenerateManyRef(1, 5)
 
 				targetGroupKey := models.GenerateGroupKey(groupKey.OrgID)
 
 				updates := make([]store.RuleDelta, 0, len(rules))
 				for _, rule := range rules {
-					cp := models.CopyRule(rule)
-					models.WithGroupKey(targetGroupKey)(cp)
-					cp.Data = []models.AlertQuery{
-						models.GenerateAlertQuery(),
-					}
+					cp := models.CopyRule(rule, gen.WithGroupKey(targetGroupKey), gen.WithQuery(gen.GenerateQuery()))
 
 					updates = append(updates, store.RuleDelta{
 						Existing: rule,
@@ -238,13 +250,9 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 			},
 			permissions: func(c *store.GroupDelta) map[string][]string {
 				dsScopes := getDatasourceScopesForRules(
-					append(append(append(c.AffectedGroups[c.GroupKey],
-						mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
-							return update.New
-						})...,
-					), mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
-						return update.Existing
-					})...), c.AffectedGroups[groupKey]...),
+					mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
+						return update.New
+					}),
 				)
 
 				var deleteScopes []string
@@ -269,8 +277,8 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 					NamespaceUID: groupKey.NamespaceUID,
 					RuleGroup:    util.GenerateShortUID(),
 				}
-				sourceGroup := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(groupKey)))
-				targetGroup := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithGroupKey(targetGroupKey)))
+				sourceGroup := genWithGroupKey.GenerateManyRef(1, 5)
+				targetGroup := gen.With(gen.WithGroupKey(targetGroupKey)).GenerateManyRef(1, 5)
 
 				updates := make([]store.RuleDelta, 0, len(sourceGroup))
 				toCopy := len(sourceGroup)
@@ -279,11 +287,7 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				}
 				for i := 0; i < toCopy; i++ {
 					rule := sourceGroup[0]
-					cp := models.CopyRule(rule)
-					models.WithGroupKey(targetGroupKey)(cp)
-					cp.Data = []models.AlertQuery{
-						models.GenerateAlertQuery(),
-					}
+					cp := models.CopyRule(rule, gen.WithGroupKey(targetGroupKey), gen.WithQuery(models.GenerateAlertQuery()))
 
 					updates = append(updates, store.RuleDelta{
 						Existing: rule,
@@ -303,27 +307,11 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				}
 			},
 			permissions: func(c *store.GroupDelta) map[string][]string {
-				scopes := make(map[string]struct{})
-				for _, update := range c.Update {
-					for _, query := range update.New.Data {
-						scopes[datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID)] = struct{}{}
-					}
-					for _, query := range update.Existing.Data {
-						scopes[datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID)] = struct{}{}
-					}
-				}
-				for _, rules := range c.AffectedGroups {
-					for _, rule := range rules {
-						for _, query := range rule.Data {
-							scopes[datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID)] = struct{}{}
-						}
-					}
-				}
-
-				dsScopes := make([]string, 0, len(scopes))
-				for key := range scopes {
-					dsScopes = append(dsScopes, key)
-				}
+				dsScopes := getDatasourceScopesForRules(
+					mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
+						return update.New
+					}),
+				)
 
 				return map[string][]string{
 					ruleRead: {
@@ -339,6 +327,85 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				}
 			},
 		},
+		{
+			name: "if there are new rules that have notification settings it should check access to all receivers",
+			changes: func() *store.GroupDelta {
+				receiverName := "test-receiver"
+				genWithNotificationSettings := genWithGroupKey.With(gen.WithNotificationSettingsGen(models.NotificationSettingsGen(models.NSMuts.WithReceiver(receiverName))))
+				return &store.GroupDelta{
+					GroupKey: groupKey,
+					New:      genWithNotificationSettings.GenerateManyRef(1, 5),
+					Update:   nil,
+					Delete:   nil,
+				}
+			},
+			permissions: func(c *store.GroupDelta) map[string][]string {
+				return map[string][]string{
+					ruleCreate: {
+						namespaceIdScope,
+					},
+					ruleRead: {
+						namespaceIdScope,
+					},
+					dashboards.ActionFoldersRead: {
+						namespaceIdScope,
+					},
+					datasources.ActionQuery:                   getDatasourceScopesForRules(c.New),
+					accesscontrol.ActionAlertingReceiversRead: getReceiverScopesForRules(c.New),
+				}
+			},
+		},
+		{
+			name: "if there are rules that modify notification settings it should check access to all receivers",
+			changes: func() *store.GroupDelta {
+				receiverName := "test-receiver"
+				genWithNotificationSettings := genWithGroupKey.With(gen.WithNotificationSettingsGen(models.NotificationSettingsGen(models.NSMuts.WithReceiver(receiverName))))
+				rules1 := genWithNotificationSettings.GenerateManyRef(1, 5)
+				rules := genWithNotificationSettings.GenerateManyRef(1, 5)
+				updates := make([]store.RuleDelta, 0, len(rules))
+
+				for _, rule := range rules {
+					cp := models.CopyRule(rule)
+					for i := range cp.NotificationSettings {
+						cp.NotificationSettings[i].Receiver = "new-receiver"
+					}
+					updates = append(updates, store.RuleDelta{
+						Existing: rule,
+						New:      cp,
+						Diff:     nil,
+					})
+				}
+
+				return &store.GroupDelta{
+					GroupKey: groupKey,
+					AffectedGroups: map[models.AlertRuleGroupKey]models.RulesGroup{
+						groupKey: append(rules, rules1...),
+					},
+					New:    nil,
+					Update: updates,
+					Delete: nil,
+				}
+			},
+			permissions: func(c *store.GroupDelta) map[string][]string {
+				return map[string][]string{
+					ruleRead: {
+						namespaceIdScope,
+					},
+					dashboards.ActionFoldersRead: {
+						namespaceIdScope,
+					},
+					ruleUpdate: {
+						namespaceIdScope,
+					},
+					datasources.ActionQuery: getDatasourceScopesForRules(mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
+						return update.New
+					})),
+					accesscontrol.ActionAlertingReceiversRead: getReceiverScopesForRules(mapUpdates(c.Update, func(update store.RuleDelta) *models.AlertRule {
+						return update.New
+					})),
+				}
+			},
+		},
 	}
 
 	for _, testCase := range testCases {
@@ -351,9 +418,7 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				permissionCombinations = permissionCombinations[0 : len(permissionCombinations)-1] // exclude all permissions
 				for _, missing := range permissionCombinations {
 					ac := &recordingAccessControlFake{}
-					srv := RuleService{
-						ac: ac,
-					}
+					srv := NewRuleService(ac)
 					err := srv.AuthorizeRuleChanges(context.Background(), createUserWithPermissions(missing), groupChanges)
 
 					assert.Errorf(t, err, "expected error because less permissions than expected were provided. Provided: %v; Expected: %v; Diff: %v", missing, permissions, cmp.Diff(permissions, missing))
@@ -361,25 +426,16 @@ func TestAuthorizeRuleChanges(t *testing.T) {
 				}
 			})
 
-			ac := &recordingAccessControlFake{
-				Callback: func(user identity.Requester, evaluator accesscontrol.Evaluator) (bool, error) {
-					response := evaluator.Evaluate(user.GetPermissions())
-					require.Truef(t, response, "provided permissions [%v] is not enough for requested permissions [%s]", permissions, evaluator.GoString())
-					return response, nil
-				},
-			}
-			srv := RuleService{
-				ac: ac,
-			}
+			ac := acimpl.ProvideAccessControl(featuremgmt.WithFeatures())
+			srv := NewRuleService(ac)
 			err := srv.AuthorizeRuleChanges(context.Background(), createUserWithPermissions(permissions), groupChanges)
 			require.NoError(t, err)
-			require.NotEmptyf(t, ac.EvaluateRecordings, "evaluation function is expected to be called but it was not.")
 		})
 	}
 }
 
 func TestCheckDatasourcePermissionsForRule(t *testing.T) {
-	rule := models.AlertRuleGen()()
+	rule := models.RuleGen.GenerateRef()
 
 	expressionByType := models.GenerateAlertQuery()
 	expressionByType.QueryType = expr.DatasourceType
@@ -413,9 +469,7 @@ func TestCheckDatasourcePermissionsForRule(t *testing.T) {
 		}
 
 		ac := &recordingAccessControlFake{}
-		svc := RuleService{
-			ac: ac,
-		}
+		svc := NewRuleService(ac)
 
 		eval := svc.AuthorizeDatasourceAccessForRule(context.Background(), createUserWithPermissions(permissions), rule)
 
@@ -429,9 +483,7 @@ func TestCheckDatasourcePermissionsForRule(t *testing.T) {
 				return false, nil
 			},
 		}
-		svc := RuleService{
-			ac: ac,
-		}
+		svc := NewRuleService(ac)
 
 		result := svc.AuthorizeDatasourceAccessForRule(context.Background(), createUserWithPermissions(nil), rule)
 
@@ -441,14 +493,8 @@ func TestCheckDatasourcePermissionsForRule(t *testing.T) {
 }
 
 func Test_authorizeAccessToRuleGroup(t *testing.T) {
-	t.Run("should return true if user has access to all datasources of all rules in group", func(t *testing.T) {
-		rules := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen())
-		var scopes []string
-		for _, rule := range rules {
-			for _, query := range rule.Data {
-				scopes = append(scopes, datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID))
-			}
-		}
+	t.Run("should succeed if user has access to all namespaces", func(t *testing.T) {
+		rules := models.RuleGen.GenerateManyRef(1, 5)
 		namespaceScopes := make([]string, 0)
 		for _, rule := range rules {
 			namespaceScopes = append(namespaceScopes, dashboards.ScopeFoldersProvider.GetResourceScopeUID(rule.NamespaceUID))
@@ -456,48 +502,77 @@ func Test_authorizeAccessToRuleGroup(t *testing.T) {
 		permissions := map[string][]string{
 			ruleRead:                     namespaceScopes,
 			dashboards.ActionFoldersRead: namespaceScopes,
-			datasources.ActionQuery:      scopes,
 		}
 		ac := &recordingAccessControlFake{}
-		svc := RuleService{
-			ac: ac,
-		}
+		svc := NewRuleService(ac)
 
 		result := svc.AuthorizeAccessToRuleGroup(context.Background(), createUserWithPermissions(permissions), rules)
 
 		require.NoError(t, result)
 		require.NotEmpty(t, ac.EvaluateRecordings)
 	})
-	t.Run("should return false if user does not have access to at least one rule in group", func(t *testing.T) {
-		f := &folder.Folder{UID: "test-folder"}
-		rules := models.GenerateAlertRules(rand.Intn(4)+1, models.AlertRuleGen(models.WithNamespace(f)))
-		var scopes []string
-		for _, rule := range rules {
-			for _, query := range rule.Data {
-				scopes = append(scopes, datasources.ScopeProvider.GetResourceScopeUID(query.DatasourceUID))
-			}
-		}
-		permissions := map[string][]string{
-			ruleRead: {
-				dashboards.ScopeFoldersProvider.GetResourceScopeUID(f.UID),
-			},
-			dashboards.ActionFoldersRead: {
-				dashboards.ScopeFoldersProvider.GetResourceScopeUID(f.UID),
-			},
-			datasources.ActionQuery: scopes,
-		}
 
-		rule := models.AlertRuleGen(models.WithNamespace(f))()
-		rules = append(rules, rule)
+	t.Run("should fail if user does not have access to namespace", func(t *testing.T) {
+		f := &folder.Folder{UID: "test-folder"}
+		gen := models.RuleGen
+		genWithFolder := gen.With(gen.WithNamespace(f))
+		rules := genWithFolder.GenerateManyRef(1, 5)
 
 		ac := &recordingAccessControlFake{}
+		svc := NewRuleService(ac)
 
-		svc := RuleService{
-			ac: ac,
-		}
-
-		result := svc.AuthorizeAccessToRuleGroup(context.Background(), createUserWithPermissions(permissions), rules)
+		result := svc.AuthorizeAccessToRuleGroup(context.Background(), createUserWithPermissions(map[string][]string{}), rules)
 
 		require.Error(t, result)
+		require.ErrorIs(t, result, ErrAuthorizationBase)
 	})
 }
+
+func TestCanReadAllRules(t *testing.T) {
+	ac := &recordingAccessControlFake{}
+	svc := NewRuleService(ac)
+
+	testCases := []struct {
+		permissions map[string][]string
+		expected    bool
+	}{
+		{
+			permissions: map[string][]string{
+				ruleRead:                     {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+				dashboards.ActionFoldersRead: {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+			},
+			expected: true,
+		},
+		{
+			permissions: make(map[string][]string),
+		},
+		{
+			permissions: map[string][]string{
+				ruleRead:                     {dashboards.ScopeFoldersProvider.GetResourceScopeUID("test")},
+				dashboards.ActionFoldersRead: {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+			},
+		},
+		{
+			permissions: map[string][]string{
+				ruleRead:                     {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+				dashboards.ActionFoldersRead: {dashboards.ScopeFoldersProvider.GetResourceScopeUID("test")},
+			},
+		},
+		{
+			permissions: map[string][]string{
+				ruleRead: {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+			},
+		},
+		{
+			permissions: map[string][]string{
+				dashboards.ActionFoldersRead: {dashboards.ScopeFoldersProvider.GetResourceAllScope()},
+			},
+		},
+	}
+
+	for _, tc := range testCases {
+		result, err := svc.CanReadAllRules(context.Background(), createUserWithPermissions(tc.permissions))
+		assert.NoError(t, err)
+		assert.Equalf(t, tc.expected, result, "permissions: %v", tc.permissions)
+	}
+}
