@@ -2,8 +2,11 @@ package remote
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
+	alertingNotify "github.com/grafana/alerting/notify"
+
 	"github.com/grafana/grafana/pkg/infra/log"
 	apimodels "github.com/grafana/grafana/pkg/services/ngalert/api/tooling/definitions"
 	"github.com/grafana/grafana/pkg/services/ngalert/models"
@@ -32,31 +35,78 @@ func (fam *RemotePrimaryForkedAlertmanager) ApplyConfig(ctx context.Context, con
 	}
 
 	if err := fam.internal.ApplyConfig(ctx, config); err != nil {
+		// An error in the internal Alertmanager shouldn't make the whole operation fail.
+		// We're replicating writes in the internal Alertmanager just for comparing and in case we need to roll back.
 		fam.log.Error("Error applying config to the internal Alertmanager", "err", err)
 	}
 	return nil
 }
 
-// TODO: save the new configuration hash in memory.
 func (fam *RemotePrimaryForkedAlertmanager) SaveAndApplyConfig(ctx context.Context, config *apimodels.PostableUserConfig) error {
+	if err := fam.remote.SaveAndApplyConfig(ctx, config); err != nil {
+		return err
+	}
+
+	if err := fam.internal.SaveAndApplyConfig(ctx, config); err != nil {
+		// An error in the internal Alertmanager shouldn't make the whole operation fail.
+		// We're replicating writes in the internal Alertmanager just for comparing and in case we need to roll back.
+		fam.log.Error("Error applying config to the internal Alertmanager", "err", err)
+	}
 	return nil
 }
 
-// TODO: save the new configuration hash in memory.
 func (fam *RemotePrimaryForkedAlertmanager) SaveAndApplyDefaultConfig(ctx context.Context) error {
+	if err := fam.remote.SaveAndApplyDefaultConfig(ctx); err != nil {
+		return fmt.Errorf("failed to send the default configuration to the remote Alertmanager: %w", err)
+	}
+
+	if err := fam.internal.SaveAndApplyDefaultConfig(ctx); err != nil {
+		// An error in the internal Alertmanager shouldn't make the whole operation fail.
+		// We're replicating writes in the internal Alertmanager just for comparing and in case we need to roll back.
+		fam.log.Error("Error applying the default configuration to the internal Alertmanager", "err", err)
+	}
 	return nil
 }
 
-func (fam *RemotePrimaryForkedAlertmanager) GetStatus() apimodels.GettableStatus {
-	return fam.remote.GetStatus()
+func (fam *RemotePrimaryForkedAlertmanager) GetStatus(ctx context.Context) (apimodels.GettableStatus, error) {
+	return fam.remote.GetStatus(ctx)
 }
 
 func (fam *RemotePrimaryForkedAlertmanager) CreateSilence(ctx context.Context, silence *apimodels.PostableSilence) (string, error) {
-	return fam.remote.CreateSilence(ctx, silence)
+	originalID := silence.ID
+	id, err := fam.remote.CreateSilence(ctx, silence)
+	if err != nil {
+		return "", err
+	}
+
+	if originalID != "" && originalID != id {
+		// ID has changed, expire the old silence before creating a new one.
+		if err := fam.internal.DeleteSilence(ctx, originalID); err != nil {
+			if errors.Is(err, alertingNotify.ErrSilenceNotFound) {
+				// This can happen if the silence was created in the remote AM without using the Grafana UI
+				// in remote primary mode, or if the silence failed to be replicated in the internal AM.
+				fam.log.Warn("Failed to delete silence in the internal Alertmanager", "err", err, "id", originalID)
+			} else {
+				fam.log.Error("Failed to delete silence in the internal Alertmanager", "err", err, "id", originalID)
+			}
+		}
+	}
+
+	silence.ID = id
+	if _, err := fam.internal.CreateSilence(ctx, silence); err != nil {
+		fam.log.Error("Error creating silence in the internal Alertmanager", "err", err, "silence", silence)
+	}
+	return id, nil
 }
 
 func (fam *RemotePrimaryForkedAlertmanager) DeleteSilence(ctx context.Context, id string) error {
-	return fam.remote.DeleteSilence(ctx, id)
+	if err := fam.remote.DeleteSilence(ctx, id); err != nil {
+		return err
+	}
+	if err := fam.internal.DeleteSilence(ctx, id); err != nil {
+		fam.log.Error("Error deleting silence in the internal Alertmanager", "err", err, "id", id)
+	}
+	return nil
 }
 
 func (fam *RemotePrimaryForkedAlertmanager) GetSilence(ctx context.Context, id string) (apimodels.GettableSilence, error) {
@@ -83,7 +133,7 @@ func (fam *RemotePrimaryForkedAlertmanager) GetReceivers(ctx context.Context) ([
 	return fam.remote.GetReceivers(ctx)
 }
 
-func (fam *RemotePrimaryForkedAlertmanager) TestReceivers(ctx context.Context, c apimodels.TestReceiversConfigBodyParams) (*notifier.TestReceiversResult, error) {
+func (fam *RemotePrimaryForkedAlertmanager) TestReceivers(ctx context.Context, c apimodels.TestReceiversConfigBodyParams) (*alertingNotify.TestReceiversResult, int, error) {
 	return fam.remote.TestReceivers(ctx, c)
 }
 
@@ -91,9 +141,8 @@ func (fam *RemotePrimaryForkedAlertmanager) TestTemplate(ctx context.Context, c
 	return fam.remote.TestTemplate(ctx, c)
 }
 
-func (fam *RemotePrimaryForkedAlertmanager) CleanUp() {
-	// No cleanup to do in the remote Alertmanager.
-	fam.internal.CleanUp()
+func (fam *RemotePrimaryForkedAlertmanager) SilenceState(ctx context.Context) (alertingNotify.SilenceState, error) {
+	return fam.remote.SilenceState(ctx)
 }
 
 func (fam *RemotePrimaryForkedAlertmanager) StopAndWait() {
