@@ -1,6 +1,10 @@
 package pluginconfig
 
-import "context"
+import (
+	"context"
+
+	"github.com/grafana/grafana/pkg/plugins/auth"
+)
 
 var _ PluginRequestConfigProvider = (*FakePluginRequestConfigProvider)(nil)
 
@@ -11,6 +15,6 @@ func NewFakePluginRequestConfigProvider() *FakePluginRequestConfigProvider {
 }
 
 // PluginRequestConfig returns a map of configuration that should be passed in a plugin request.
-func (s *FakePluginRequestConfigProvider) PluginRequestConfig(ctx context.Context, pluginID string) map[string]string {
+func (s *FakePluginRequestConfigProvider) PluginRequestConfig(ctx context.Context, pluginID string, externalService *auth.ExternalService) map[string]string {
 	return map[string]string{}
 }
