@@ -8,8 +8,13 @@ import (
 
 	"github.com/grafana/grafana/pkg/infra/db"
 	"github.com/grafana/grafana/pkg/services/quota"
+	"github.com/grafana/grafana/pkg/tests/testsuite"
 )
 
+func TestMain(m *testing.M) {
+	testsuite.Run(m)
+}
+
 func TestIntegrationQuotaDataAccess(t *testing.T) {
 	if testing.Short() {
 		t.Skip("skipping integration test")
