@@ -14,8 +14,17 @@ import (
 
 func Test_UsageStats(t *testing.T) {
 	acSvc := actest.FakeService{}
+	pSvc := actest.FakePermissionsService{}
 	storeMock := newServiceAccountStoreFake()
-	svc := ServiceAccountsService{acSvc, storeMock, log.New("test"), log.New("background-test"), &SecretsCheckerFake{}, true, 5}
+	svc := ServiceAccountsService{
+		acService:          acSvc,
+		permissions:        &pSvc,
+		store:              storeMock,
+		log:                log.NewNopLogger(),
+		secretScanService:  &SecretsCheckerFake{},
+		secretScanEnabled:  true,
+		secretScanInterval: 5,
+	}
 	err := svc.DeleteServiceAccount(context.Background(), 1, 1)
 	require.NoError(t, err)
 
