@@ -2,12 +2,13 @@ package permissions
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"slices"
 	"strings"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/services/accesscontrol"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/dashboards/dashboardaccess"
 	"github.com/grafana/grafana/pkg/services/featuremgmt"
@@ -25,10 +26,12 @@ type clause struct {
 }
 
 type accessControlDashboardPermissionFilter struct {
-	user             identity.Requester
-	dashboardActions []string
-	folderActions    []string
-	features         featuremgmt.FeatureToggles
+	user                identity.Requester
+	dashboardAction     string
+	dashboardActionSets []string
+	folderAction        string
+	folderActionSets    []string
+	features            featuremgmt.FeatureToggles
 
 	where clause
 	// any recursive CTE queries (if supported)
@@ -51,38 +54,65 @@ type PermissionsFilter interface {
 func NewAccessControlDashboardPermissionFilter(user identity.Requester, permissionLevel dashboardaccess.PermissionType, queryType string, features featuremgmt.FeatureToggles, recursiveQueriesAreSupported bool) PermissionsFilter {
 	needEdit := permissionLevel > dashboardaccess.PERMISSION_VIEW
 
-	var folderActions []string
-	var dashboardActions []string
+	var folderAction string
+	var dashboardAction string
+	var folderActionSets []string
+	var dashboardActionSets []string
 	if queryType == searchstore.TypeFolder {
-		folderActions = append(folderActions, dashboards.ActionFoldersRead)
+		folderAction = dashboards.ActionFoldersRead
+		if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+			folderActionSets = []string{"folders:view", "folders:edit", "folders:admin"}
+		}
 		if needEdit {
-			folderActions = append(folderActions, dashboards.ActionDashboardsCreate)
+			folderAction = dashboards.ActionDashboardsCreate
+			if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+				folderActionSets = []string{"folders:edit", "folders:admin"}
+			}
 		}
 	} else if queryType == searchstore.TypeDashboard {
-		dashboardActions = append(dashboardActions, dashboards.ActionDashboardsRead)
+		dashboardAction = dashboards.ActionDashboardsRead
+		if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+			folderActionSets = []string{"folders:view", "folders:edit", "folders:admin"}
+			dashboardActionSets = []string{"dashboards:view", "dashboards:edit", "dashboards:admin"}
+		}
 		if needEdit {
-			dashboardActions = append(dashboardActions, dashboards.ActionDashboardsWrite)
+			dashboardAction = dashboards.ActionDashboardsWrite
+			if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+				folderActionSets = []string{"folders:edit", "folders:admin"}
+				dashboardActionSets = []string{"dashboards:edit", "dashboards:admin"}
+			}
 		}
 	} else if queryType == searchstore.TypeAlertFolder {
-		folderActions = append(
-			folderActions,
-			dashboards.ActionFoldersRead,
-			accesscontrol.ActionAlertingRuleRead,
-		)
+		folderAction = accesscontrol.ActionAlertingRuleRead
+		if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+			folderActionSets = []string{"folders:view", "folders:edit", "folders:admin"}
+		}
 		if needEdit {
-			folderActions = append(
-				folderActions,
-				accesscontrol.ActionAlertingRuleCreate,
-			)
+			folderAction = accesscontrol.ActionAlertingRuleCreate
+			if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+				folderActionSets = []string{"folders:edit", "folders:admin"}
+			}
 		}
 	} else if queryType == searchstore.TypeAnnotation {
-		dashboardActions = append(dashboardActions, accesscontrol.ActionAnnotationsRead)
+		dashboardAction = accesscontrol.ActionAnnotationsRead
+		if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+			folderActionSets = []string{"folders:view", "folders:edit", "folders:admin"}
+			dashboardActionSets = []string{"dashboards:view", "dashboards:edit", "dashboards:admin"}
+		}
 	} else {
-		folderActions = append(folderActions, dashboards.ActionFoldersRead)
-		dashboardActions = append(dashboardActions, dashboards.ActionDashboardsRead)
+		folderAction = dashboards.ActionFoldersRead
+		dashboardAction = dashboards.ActionDashboardsRead
+		if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+			folderActionSets = []string{"folders:view", "folders:edit", "folders:admin"}
+			dashboardActionSets = []string{"dashboards:view", "dashboards:edit", "dashboards:admin"}
+		}
 		if needEdit {
-			folderActions = append(folderActions, dashboards.ActionDashboardsCreate)
-			dashboardActions = append(dashboardActions, dashboards.ActionDashboardsWrite)
+			folderAction = dashboards.ActionDashboardsCreate
+			dashboardAction = dashboards.ActionDashboardsWrite
+			if features.IsEnabled(context.Background(), featuremgmt.FlagAccessActionSets) {
+				folderActionSets = []string{"folders:edit", "folders:admin"}
+				dashboardActionSets = []string{"dashboards:edit", "dashboards:admin"}
+			}
 		}
 	}
 
@@ -90,13 +120,13 @@ func NewAccessControlDashboardPermissionFilter(user identity.Requester, permissi
 	if features.IsEnabledGlobally(featuremgmt.FlagPermissionsFilterRemoveSubquery) {
 		f = &accessControlDashboardPermissionFilterNoFolderSubquery{
 			accessControlDashboardPermissionFilter: accessControlDashboardPermissionFilter{
-				user: user, folderActions: folderActions, dashboardActions: dashboardActions, features: features,
-				recursiveQueriesAreSupported: recursiveQueriesAreSupported,
+				user: user, folderAction: folderAction, folderActionSets: folderActionSets, dashboardAction: dashboardAction, dashboardActionSets: dashboardActionSets,
+				features: features, recursiveQueriesAreSupported: recursiveQueriesAreSupported,
 			},
 		}
 	} else {
-		f = &accessControlDashboardPermissionFilter{user: user, folderActions: folderActions, dashboardActions: dashboardActions, features: features,
-			recursiveQueriesAreSupported: recursiveQueriesAreSupported,
+		f = &accessControlDashboardPermissionFilter{user: user, folderAction: folderAction, folderActionSets: folderActionSets, dashboardAction: dashboardAction, dashboardActionSets: dashboardActionSets,
+			features: features, recursiveQueriesAreSupported: recursiveQueriesAreSupported,
 		}
 	}
 	f.buildClauses()
@@ -114,19 +144,30 @@ func (f *accessControlDashboardPermissionFilter) Where() (string, []any) {
 	return f.where.string, f.where.params
 }
 
+// Check if user has no permissions required for search to skip expensive query
+func (f *accessControlDashboardPermissionFilter) hasRequiredActions() bool {
+	permissions := f.user.GetPermissions()
+	requiredActions := []string{f.folderAction, f.dashboardAction}
+	for _, action := range requiredActions {
+		if _, ok := permissions[action]; ok {
+			return true
+		}
+	}
+
+	return false
+}
+
 func (f *accessControlDashboardPermissionFilter) buildClauses() {
-	if f.user == nil || f.user.IsNil() || len(f.user.GetPermissions()) == 0 {
+	if f.user == nil || f.user.IsNil() || !f.hasRequiredActions() {
 		f.where = clause{string: "(1 = 0)"}
 		return
 	}
 	dashWildcards := accesscontrol.WildcardsFromPrefix(dashboards.ScopeDashboardsPrefix)
 	folderWildcards := accesscontrol.WildcardsFromPrefix(dashboards.ScopeFoldersPrefix)
 
-	userID := int64(0)
-	namespaceID, identifier := f.user.GetNamespacedID()
-	switch namespaceID {
-	case identity.NamespaceUser, identity.NamespaceServiceAccount:
-		userID, _ = identity.IntIdentifier(namespaceID, identifier)
+	var userID int64
+	if id, err := identity.UserIdentifier(f.user.GetID()); err == nil {
+		userID = id
 	}
 
 	orgID := f.user.GetOrgID()
@@ -143,28 +184,24 @@ func (f *accessControlDashboardPermissionFilter) buildClauses() {
 	// currently it's used for the extended JWT module (when the user is authenticated via a JWT token generated by Grafana)
 	useSelfContainedPermissions := f.user.IsAuthenticatedBy(login.ExtendedJWTModule)
 
-	if len(f.dashboardActions) > 0 {
-		toCheck := actionsToCheck(f.dashboardActions, f.user.GetPermissions(), dashWildcards, folderWildcards)
+	if f.dashboardAction != "" {
+		toCheckDashboards := actionsToCheck(f.dashboardAction, f.dashboardActionSets, f.user.GetPermissions(), dashWildcards, folderWildcards)
+		toCheckFolders := actionsToCheck(f.dashboardAction, f.folderActionSets, f.user.GetPermissions(), dashWildcards, folderWildcards)
 
-		if len(toCheck) > 0 {
+		if len(toCheckDashboards) > 0 {
 			if !useSelfContainedPermissions {
 				builder.WriteString("(dashboard.uid IN (SELECT identifier FROM permission WHERE kind = 'dashboards' AND attribute = 'uid'")
 				builder.WriteString(rolesFilter)
 				args = append(args, params...)
-
-				if len(toCheck) == 1 {
-					builder.WriteString(" AND action = ?")
-					args = append(args, toCheck[0])
+				if len(toCheckDashboards) == 1 {
+					builder.WriteString(" AND action = ?) AND NOT dashboard.is_folder)")
+					args = append(args, toCheckDashboards[0])
 				} else {
-					builder.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheck)-1) + ") GROUP BY role_id, scope, identifier HAVING COUNT(action) = ?")
-					args = append(args, toCheck...)
-					args = append(args, len(toCheck))
+					builder.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheckDashboards)-1) + ")) AND NOT dashboard.is_folder)")
+					args = append(args, toCheckDashboards...)
 				}
-				builder.WriteString(") AND NOT dashboard.is_folder)")
 			} else {
-				actions := parseStringSliceFromInterfaceSlice(toCheck)
-
-				args = getAllowedUIDs(actions, f.user, dashboards.ScopeDashboardsPrefix)
+				args = getAllowedUIDs(f.dashboardAction, f.user, dashboards.ScopeDashboardsPrefix)
 
 				// Only add the IN clause if we have any dashboards to check
 				if len(args) > 0 {
@@ -181,19 +218,15 @@ func (f *accessControlDashboardPermissionFilter) buildClauses() {
 				permSelector.WriteString("(SELECT identifier FROM permission WHERE kind = 'folders' AND attribute = 'uid'")
 				permSelector.WriteString(rolesFilter)
 				permSelectorArgs = append(permSelectorArgs, params...)
-
-				if len(toCheck) == 1 {
+				if len(toCheckDashboards) == 1 {
 					permSelector.WriteString(" AND action = ?")
-					permSelectorArgs = append(permSelectorArgs, toCheck[0])
+					permSelectorArgs = append(permSelectorArgs, toCheckDashboards[0])
 				} else {
-					permSelector.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheck)-1) + ") GROUP BY role_id, scope, identifier HAVING COUNT(action) = ?")
-					permSelectorArgs = append(permSelectorArgs, toCheck...)
-					permSelectorArgs = append(permSelectorArgs, len(toCheck))
+					permSelector.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheckDashboards)-1) + ")")
+					permSelectorArgs = append(permSelectorArgs, toCheckFolders...)
 				}
 			} else {
-				actions := parseStringSliceFromInterfaceSlice(toCheck)
-
-				permSelectorArgs = getAllowedUIDs(actions, f.user, dashboards.ScopeFoldersPrefix)
+				permSelectorArgs = getAllowedUIDs(f.dashboardAction, f.user, dashboards.ScopeFoldersPrefix)
 
 				// Only add the IN clause if we have any folders to check
 				if len(permSelectorArgs) > 0 {
@@ -238,7 +271,7 @@ func (f *accessControlDashboardPermissionFilter) buildClauses() {
 			builder.WriteString(") AND NOT dashboard.is_folder)")
 
 			// Include all the dashboards under the root if the user has the required permissions on the root (used to be the General folder)
-			if hasAccessToRoot(toCheck, f.user) {
+			if hasAccessToRoot(f.dashboardAction, f.user) {
 				builder.WriteString(" OR (dashboard.folder_id = 0 AND NOT dashboard.is_folder)")
 			}
 		} else {
@@ -250,12 +283,13 @@ func (f *accessControlDashboardPermissionFilter) buildClauses() {
 	permSelector.Reset()
 	permSelectorArgs = permSelectorArgs[:0]
 
-	if len(f.folderActions) > 0 {
-		if len(f.dashboardActions) > 0 {
+	if f.folderAction != "" {
+		if f.dashboardAction != "" {
 			builder.WriteString(" OR ")
 		}
 
-		toCheck := actionsToCheck(f.folderActions, f.user.GetPermissions(), folderWildcards)
+		toCheck := actionsToCheck(f.folderAction, f.folderActionSets, f.user.GetPermissions(), folderWildcards)
+
 		if len(toCheck) > 0 {
 			if !useSelfContainedPermissions {
 				permSelector.WriteString("(SELECT identifier FROM permission WHERE kind = 'folders' AND attribute = 'uid'")
@@ -265,14 +299,11 @@ func (f *accessControlDashboardPermissionFilter) buildClauses() {
 					permSelector.WriteString(" AND action = ?")
 					permSelectorArgs = append(permSelectorArgs, toCheck[0])
 				} else {
-					permSelector.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheck)-1) + ") GROUP BY role_id, scope, identifier HAVING COUNT(action) = ?")
+					permSelector.WriteString(" AND action IN (?" + strings.Repeat(", ?", len(toCheck)-1) + ")")
 					permSelectorArgs = append(permSelectorArgs, toCheck...)
-					permSelectorArgs = append(permSelectorArgs, len(toCheck))
 				}
 			} else {
-				actions := parseStringSliceFromInterfaceSlice(toCheck)
-
-				permSelectorArgs = getAllowedUIDs(actions, f.user, dashboards.ScopeFoldersPrefix)
+				permSelectorArgs = getAllowedUIDs(f.folderAction, f.user, dashboards.ScopeFoldersPrefix)
 
 				if len(permSelectorArgs) > 0 {
 					permSelector.WriteString("(?" + strings.Repeat(", ?", len(permSelectorArgs)-1) + "")
@@ -357,26 +388,20 @@ func (f *accessControlDashboardPermissionFilter) addRecQry(queryName string, whe
 	})
 }
 
-func actionsToCheck(actions []string, permissions map[string][]string, wildcards ...accesscontrol.Wildcards) []any {
-	toCheck := make([]any, 0, len(actions))
-
-	for _, a := range actions {
-		var hasWildcard bool
-
-	outer:
-		for _, scope := range permissions[a] {
-			for _, w := range wildcards {
-				if w.Contains(scope) {
-					hasWildcard = true
-					break outer
-				}
+func actionsToCheck(action string, actionSets []string, permissions map[string][]string, wildcards ...accesscontrol.Wildcards) []any {
+	for _, scope := range permissions[action] {
+		for _, w := range wildcards {
+			if w.Contains(scope) {
+				return []any{}
 			}
 		}
-
-		if !hasWildcard {
-			toCheck = append(toCheck, a)
-		}
 	}
+
+	toCheck := []any{action}
+	for _, a := range actionSets {
+		toCheck = append(toCheck, a)
+	}
+
 	return toCheck
 }
 
@@ -408,46 +433,23 @@ func (f *accessControlDashboardPermissionFilter) nestedFoldersSelectors(permSele
 	return strings.Join(wheres, ") OR "), args
 }
 
-func parseStringSliceFromInterfaceSlice(slice []any) []string {
-	result := make([]string, 0, len(slice))
-	for _, s := range slice {
-		result = append(result, s.(string))
-	}
-	return result
-}
+func getAllowedUIDs(action string, user identity.Requester, scopePrefix string) []any {
+	uidScopes := user.GetPermissions()[action]
 
-func getAllowedUIDs(actions []string, user identity.Requester, scopePrefix string) []any {
-	uidToActions := make(map[string]map[string]struct{})
-	for _, action := range actions {
-		for _, uidScope := range user.GetPermissions()[action] {
-			if !strings.HasPrefix(uidScope, scopePrefix) {
-				continue
-			}
-			uid := strings.TrimPrefix(uidScope, scopePrefix)
-			if _, exists := uidToActions[uid]; !exists {
-				uidToActions[uid] = make(map[string]struct{})
-			}
-			uidToActions[uid][action] = struct{}{}
+	args := make([]any, 0, len(uidScopes))
+	for _, uidScope := range uidScopes {
+		if !strings.HasPrefix(uidScope, scopePrefix) {
+			continue
 		}
+		uid := strings.TrimPrefix(uidScope, scopePrefix)
+		args = append(args, uid)
 	}
 
-	// args max capacity is the length of the different uids
-	args := make([]any, 0, len(uidToActions))
-	for uid, assignedActions := range uidToActions {
-		if len(assignedActions) == len(actions) {
-			args = append(args, uid)
-		}
-	}
 	return args
 }
 
 // Checks if the user has the required permissions on the root (used to be the General folder)
-func hasAccessToRoot(actionsToCheck []any, user identity.Requester) bool {
+func hasAccessToRoot(actionToCheck string, user identity.Requester) bool {
 	generalFolderScope := dashboards.ScopeFoldersProvider.GetResourceScopeUID(folder.GeneralFolderUID)
-	for _, action := range actionsToCheck {
-		if !slices.Contains(user.GetPermissions()[action.(string)], generalFolderScope) {
-			return false
-		}
-	}
-	return true
+	return slices.Contains(user.GetPermissions()[actionToCheck], generalFolderScope)
 }
