@@ -16,7 +16,7 @@ import (
 const mainOrgName = "Main Org."
 
 func (ss *SQLStore) getOrgIDForNewUser(sess *DBSession, args user.CreateUserCommand) (int64, error) {
-	if ss.Cfg.AutoAssignOrg && args.OrgID != 0 {
+	if ss.cfg.AutoAssignOrg && args.OrgID != 0 {
 		if err := verifyExistingOrg(sess, args.OrgID); err != nil {
 			return -1, err
 		}
@@ -64,6 +64,7 @@ func (ss *SQLStore) createUser(ctx context.Context, sess *DBSession, args user.C
 
 	// create user
 	usr = user.User{
+		UID:        util.GenerateShortUID(),
 		Email:      args.Email,
 		Login:      args.Login,
 		IsAdmin:    args.IsAdmin,
@@ -114,11 +115,11 @@ func (ss *SQLStore) createUser(ctx context.Context, sess *DBSession, args user.C
 		Updated: time.Now(),
 	}
 
-	if ss.Cfg.AutoAssignOrg && !usr.IsAdmin {
+	if ss.cfg.AutoAssignOrg && !usr.IsAdmin {
 		if len(args.DefaultOrgRole) > 0 {
 			orgUser.Role = org.RoleType(args.DefaultOrgRole)
 		} else {
-			orgUser.Role = org.RoleType(ss.Cfg.AutoAssignOrgRole)
+			orgUser.Role = org.RoleType(ss.cfg.AutoAssignOrgRole)
 		}
 	}
 
@@ -144,8 +145,8 @@ func verifyExistingOrg(sess *DBSession, orgId int64) error {
 func (ss *SQLStore) getOrCreateOrg(sess *DBSession, orgName string) (int64, error) {
 	var org org.Org
 
-	if ss.Cfg.AutoAssignOrg {
-		has, err := sess.Where("id=?", ss.Cfg.AutoAssignOrgId).Get(&org)
+	if ss.cfg.AutoAssignOrg {
+		has, err := sess.Where("id=?", ss.cfg.AutoAssignOrgId).Get(&org)
 		if err != nil {
 			return 0, err
 		}
@@ -154,18 +155,18 @@ func (ss *SQLStore) getOrCreateOrg(sess *DBSession, orgName string) (int64, erro
 		}
 		ss.log.Debug("auto assigned organization not found")
 
-		if ss.Cfg.AutoAssignOrgId != 1 {
+		if ss.cfg.AutoAssignOrgId != 1 {
 			ss.log.Error("Could not create user: organization ID does not exist", "orgID",
-				ss.Cfg.AutoAssignOrgId)
+				ss.cfg.AutoAssignOrgId)
 			return 0, fmt.Errorf("could not create user: organization ID %d does not exist",
-				ss.Cfg.AutoAssignOrgId)
+				ss.cfg.AutoAssignOrgId)
 		}
 
 		org.Name = mainOrgName
 		org.Created = time.Now()
 		org.Updated = org.Created
-		org.ID = int64(ss.Cfg.AutoAssignOrgId)
-		if err := sess.InsertId(&org, ss.Dialect); err != nil {
+		org.ID = int64(ss.cfg.AutoAssignOrgId)
+		if err := sess.InsertId(&org, ss.dialect); err != nil {
 			ss.log.Error("failed to insert organization with provided id", "org_id", org.ID, "err", err)
 			// ignore failure if for some reason the organization exists
 			if ss.GetDialect().IsUniqueConstraintViolation(err) {
