@@ -1,7 +1,7 @@
 package ssosettings
 
 import (
-	"github.com/grafana/grafana/pkg/util/errutil"
+	"github.com/grafana/grafana/pkg/apimachinery/errutil"
 )
 
 var (
