@@ -19,8 +19,11 @@ var (
 	enabled = true
 	allow_sign_up = false
 	auto_login = true
+	client_authentication = test_client_authentication
 	client_id = test_client_id
 	client_secret = test_client_secret
+	managed_identity_client_id = test_managed_identity_client_id
+	federated_credential_audience = test_federated_credential_audience
 	scopes = openid, profile, email
 	empty_scopes = false
 	email_attribute_name = email:primary
@@ -52,46 +55,53 @@ var (
 	empty_scopes =
 	hosted_domain = test_hosted_domain
 	signout_redirect_url = test_signout_redirect_url
+	org_attribute_path = groups
+	org_mapping = Group1:*:Editor
 	`
 
 	expectedOAuthInfo = map[string]any{
-		"name":                       "OAuth",
-		"icon":                       "signin",
-		"enabled":                    true,
-		"allow_sign_up":              false,
-		"auto_login":                 true,
-		"client_id":                  "test_client_id",
-		"client_secret":              "test_client_secret",
-		"scopes":                     "openid, profile, email",
-		"empty_scopes":               false,
-		"email_attribute_name":       "email:primary",
-		"email_attribute_path":       "email",
-		"role_attribute_path":        "role",
-		"role_attribute_strict":      true,
-		"groups_attribute_path":      "groups",
-		"team_ids_attribute_path":    "team_ids",
-		"auth_url":                   "test_auth_url",
-		"token_url":                  "test_token_url",
-		"api_url":                    "test_api_url",
-		"teams_url":                  "test_teams_url",
-		"allowed_domains":            "domain1.com",
-		"allowed_groups":             "",
-		"tls_skip_verify_insecure":   true,
-		"tls_client_cert":            "",
-		"tls_client_key":             "",
-		"tls_client_ca":              "",
-		"use_pkce":                   false,
-		"auth_style":                 "inheader",
-		"allow_assign_grafana_admin": true,
-		"use_refresh_token":          true,
-		"hosted_domain":              "test_hosted_domain",
-		"skip_org_role_sync":         true,
-		"signout_redirect_url":       "test_signout_redirect_url",
-		"allowed_organizations":      "org1, org2",
-		"id_token_attribute_name":    "id_token",
-		"login_attribute_path":       "login",
-		"name_attribute_path":        "name",
-		"team_ids":                   "first, second",
+		"name":                          "OAuth",
+		"icon":                          "signin",
+		"enabled":                       true,
+		"allow_sign_up":                 false,
+		"auto_login":                    true,
+		"client_authentication":         "test_client_authentication",
+		"client_id":                     "test_client_id",
+		"client_secret":                 "test_client_secret",
+		"managed_identity_client_id":    "test_managed_identity_client_id",
+		"federated_credential_audience": "test_federated_credential_audience",
+		"scopes":                        "openid, profile, email",
+		"empty_scopes":                  false,
+		"email_attribute_name":          "email:primary",
+		"email_attribute_path":          "email",
+		"role_attribute_path":           "role",
+		"role_attribute_strict":         true,
+		"groups_attribute_path":         "groups",
+		"team_ids_attribute_path":       "team_ids",
+		"auth_url":                      "test_auth_url",
+		"token_url":                     "test_token_url",
+		"api_url":                       "test_api_url",
+		"teams_url":                     "test_teams_url",
+		"allowed_domains":               "domain1.com",
+		"allowed_groups":                "",
+		"tls_skip_verify_insecure":      true,
+		"tls_client_cert":               "",
+		"tls_client_key":                "",
+		"tls_client_ca":                 "",
+		"use_pkce":                      false,
+		"auth_style":                    "inheader",
+		"allow_assign_grafana_admin":    true,
+		"use_refresh_token":             true,
+		"hosted_domain":                 "test_hosted_domain",
+		"skip_org_role_sync":            true,
+		"signout_redirect_url":          "test_signout_redirect_url",
+		"allowed_organizations":         "org1, org2",
+		"id_token_attribute_name":       "id_token",
+		"login_attribute_path":          "login",
+		"name_attribute_path":           "name",
+		"team_ids":                      "first, second",
+		"org_attribute_path":            "groups",
+		"org_mapping":                   "Group1:*:Editor",
 	}
 )
 
