@@ -32,6 +32,7 @@ type PluginsService struct {
 	mutex          sync.RWMutex
 	log            log.Logger
 	tracer         tracing.Tracer
+	updateCheckURL *url.URL
 }
 
 func ProvidePluginsService(cfg *setting.Cfg, pluginStore pluginstore.Store, tracer tracing.Tracer) (*PluginsService, error) {
@@ -45,6 +46,16 @@ func ProvidePluginsService(cfg *setting.Cfg, pluginStore pluginstore.Store, trac
 		return nil, err
 	}
 
+	updateCheckURL, err := url.JoinPath(cfg.GrafanaComAPIURL, "plugins", "versioncheck")
+	if err != nil {
+		return nil, err
+	}
+
+	parsedUpdateCheckURL, err := url.Parse(updateCheckURL)
+	if err != nil {
+		return nil, err
+	}
+
 	return &PluginsService{
 		enabled:          cfg.CheckForPluginUpdates,
 		grafanaVersion:   cfg.BuildVersion,
@@ -53,6 +64,7 @@ func ProvidePluginsService(cfg *setting.Cfg, pluginStore pluginstore.Store, trac
 		tracer:           tracer,
 		pluginStore:      pluginStore,
 		availableUpdates: make(map[string]string),
+		updateCheckURL:   parsedUpdateCheckURL,
 	}, nil
 }
 
@@ -113,13 +125,16 @@ func (s *PluginsService) instrumentedCheckForUpdates(ctx context.Context) {
 
 func (s *PluginsService) checkForUpdates(ctx context.Context) error {
 	ctxLogger := s.log.FromContext(ctx)
-	ctxLogger.Debug("Checking for updates")
+	ctxLogger.Debug("Preparing plugins eligible for version check")
 	localPlugins := s.pluginsEligibleForVersionCheck(ctx)
-	requestURL := "https://grafana.com/api/plugins/versioncheck?" + url.Values{
-		"slugIn":         []string{s.pluginIDsCSV(localPlugins)},
-		"grafanaVersion": []string{s.grafanaVersion},
-	}.Encode()
-	req, err := http.NewRequestWithContext(ctx, http.MethodGet, requestURL, nil)
+	requestURL := s.updateCheckURL
+	requestURLParameters := requestURL.Query()
+	requestURLParameters.Set("slugIn", s.pluginIDsCSV((localPlugins)))
+	requestURLParameters.Set("grafanaVersion", s.grafanaVersion)
+	requestURL.RawQuery = requestURLParameters.Encode()
+
+	ctxLogger.Debug("Checking for plugin updates", "url", requestURL)
+	req, err := http.NewRequestWithContext(ctx, http.MethodGet, requestURL.String(), nil)
 	if err != nil {
 		return err
 	}
