@@ -2,6 +2,7 @@ package alerting
 
 import (
 	"bytes"
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -20,10 +21,19 @@ import (
 
 	"github.com/grafana/grafana/pkg/api"
 	"github.com/grafana/grafana/pkg/expr"
+	"github.com/grafana/grafana/pkg/infra/db"
+	"github.com/grafana/grafana/pkg/infra/tracing"
+	"github.com/grafana/grafana/pkg/services/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/folder"
 	apimodels "github.com/grafana/grafana/pkg/services/ngalert/api/tooling/definitions"
 	ngmodels "github.com/grafana/grafana/pkg/services/ngalert/models"
+	"github.com/grafana/grafana/pkg/services/org/orgimpl"
 	"github.com/grafana/grafana/pkg/services/quota"
+	"github.com/grafana/grafana/pkg/services/quota/quotaimpl"
+	"github.com/grafana/grafana/pkg/services/supportbundles/supportbundlestest"
+	"github.com/grafana/grafana/pkg/services/user"
+	"github.com/grafana/grafana/pkg/services/user/userimpl"
+	"github.com/grafana/grafana/pkg/setting"
 	"github.com/grafana/grafana/pkg/util"
 )
 
@@ -35,7 +45,6 @@ const defaultAlertmanagerConfigJSON = `
 			"receiver": "grafana-default-email",
 			"group_by": ["grafana_folder", "alertname"]
 		},
-		"templates": null,
 		"receivers": [{
 			"name": "grafana-default-email",
 			"grafana_managed_receiver_configs": [{
@@ -53,6 +62,11 @@ const defaultAlertmanagerConfigJSON = `
 }
 `
 
+type Response struct {
+	Message string `json:"message"`
+	TraceID string `json:"traceID"`
+}
+
 func getRequest(t *testing.T, url string, expStatusCode int) *http.Response {
 	t.Helper()
 	// nolint:gosec
@@ -234,6 +248,7 @@ func convertGettableGrafanaRuleToPostable(gettable *apimodels.GettableGrafanaRul
 		ExecErrState:         gettable.ExecErrState,
 		IsPaused:             &gettable.IsPaused,
 		NotificationSettings: gettable.NotificationSettings,
+		Metadata:             gettable.Metadata,
 	}
 }
 
@@ -241,6 +256,17 @@ type apiClient struct {
 	url string
 }
 
+type LegacyApiClient struct {
+	apiClient
+}
+
+func NewAlertingLegacyAPIClient(host, user, pass string) LegacyApiClient {
+	cli := newAlertingApiClient(host, user, pass)
+	return LegacyApiClient{
+		apiClient: cli,
+	}
+}
+
 func newAlertingApiClient(host, user, pass string) apiClient {
 	if len(user) == 0 && len(pass) == 0 {
 		return apiClient{url: fmt.Sprintf("http://%s", host)}
@@ -262,6 +288,42 @@ func (a apiClient) ReloadCachedPermissions(t *testing.T) {
 	require.Equalf(t, http.StatusOK, resp.StatusCode, "failed to reload permissions cache")
 }
 
+// AssignReceiverPermission sends a request to access control API to assign permissions to a user, role, or team on a receiver.
+func (a apiClient) AssignReceiverPermission(t *testing.T, receiverUID string, cmd accesscontrol.SetResourcePermissionCommand) (int, string) {
+	t.Helper()
+
+	var assignment string
+	var assignTo string
+	if cmd.UserID != 0 {
+		assignment = "users"
+		assignTo = fmt.Sprintf("%d", cmd.UserID)
+	} else if cmd.TeamID != 0 {
+		assignment = "teams"
+		assignTo = fmt.Sprintf("%d", cmd.TeamID)
+	} else {
+		assignment = "builtInRoles"
+		assignTo = cmd.BuiltinRole
+	}
+
+	body := strings.NewReader(fmt.Sprintf(`{"permission": "%s"}`, cmd.Permission))
+	req, err := http.NewRequest(http.MethodPost, fmt.Sprintf("%s/api/access-control/receivers/%s/%s/%s", a.url, receiverUID, assignment, assignTo), body)
+	require.NoError(t, err)
+	req.Header.Set("Content-Type", "application/json")
+
+	client := &http.Client{}
+	resp, err := client.Do(req)
+	require.NoError(t, err)
+	require.NotNil(t, resp)
+
+	defer func() {
+		_ = resp.Body.Close()
+	}()
+	b, err := io.ReadAll(resp.Body)
+	require.NoError(t, err)
+
+	return resp.StatusCode, string(b)
+}
+
 // CreateFolder creates a folder for storing our alerts, and then refreshes the permission cache to make sure that following requests will be accepted
 func (a apiClient) CreateFolder(t *testing.T, uID string, title string, parentUID ...string) {
 	t.Helper()
@@ -289,6 +351,19 @@ func (a apiClient) CreateFolder(t *testing.T, uID string, title string, parentUI
 	a.ReloadCachedPermissions(t)
 }
 
+func (a apiClient) ReloadAlertingFileProvisioning(t *testing.T) {
+	t.Helper()
+
+	u := fmt.Sprintf("%s/api/admin/provisioning/alerting/reload", a.url)
+	// nolint:gosec
+	resp, err := http.Post(u, "application/json", nil)
+	defer func() {
+		require.NoError(t, resp.Body.Close())
+	}()
+	require.NoError(t, err)
+	assert.Equal(t, http.StatusOK, resp.StatusCode)
+}
+
 func (a apiClient) GetOrgQuotaLimits(t *testing.T, orgID int64) (int64, int64) {
 	t.Helper()
 
@@ -454,39 +529,50 @@ func (a apiClient) DeleteRulesGroup(t *testing.T, folder string, group string) (
 	return resp.StatusCode, string(b)
 }
 
-func (a apiClient) PostSilence(t *testing.T, s apimodels.PostableSilence) (string, error) {
+func (a apiClient) PostSilence(t *testing.T, s apimodels.PostableSilence) (apimodels.PostSilencesOKBody, int, string) {
 	t.Helper()
 
 	b, err := json.Marshal(s)
 	require.NoError(t, err)
 
-	u := fmt.Sprintf("%s/api/alertmanager/grafana/api/v2/silences", a.url)
-	req, err := http.NewRequest(http.MethodPost, u, bytes.NewReader(b))
+	req, err := http.NewRequest(http.MethodPost, fmt.Sprintf("%s/api/alertmanager/grafana/api/v2/silences", a.url), bytes.NewReader(b))
 	require.NoError(t, err)
 	req.Header.Set("Content-Type", "application/json")
+	return sendRequest[apimodels.PostSilencesOKBody](t, req, http.StatusAccepted)
+}
 
-	client := &http.Client{}
-	resp, err := client.Do(req)
+func (a apiClient) GetSilence(t *testing.T, id string) (apimodels.GettableSilence, int, string) {
+	t.Helper()
+	req, err := http.NewRequest(http.MethodGet, fmt.Sprintf("%s/api/alertmanager/grafana/api/v2/silence/%s", a.url, id), nil)
 	require.NoError(t, err)
-	require.NotNil(t, resp)
+	return sendRequest[apimodels.GettableSilence](t, req, http.StatusOK)
+}
 
-	defer func() {
-		_ = resp.Body.Close()
-	}()
-	b, err = io.ReadAll(resp.Body)
+func (a apiClient) GetSilences(t *testing.T, filters ...string) (apimodels.GettableSilences, int, string) {
+	t.Helper()
+
+	u, err := url.Parse(fmt.Sprintf("%s/api/alertmanager/grafana/api/v2/silences", a.url))
 	require.NoError(t, err)
-
-	data := struct {
-		SilenceID string `json:"silenceID"`
-		Message   string `json:"message"`
-	}{}
-	require.NoError(t, json.Unmarshal(b, &data))
-
-	if resp.StatusCode == http.StatusAccepted {
-		return data.SilenceID, nil
+	if len(filters) > 0 {
+		u.RawQuery = url.Values{"filter": filters}.Encode()
 	}
 
-	return "", errors.New(data.Message)
+	req, err := http.NewRequest(http.MethodGet, u.String(), nil)
+	require.NoError(t, err)
+
+	return sendRequest[apimodels.GettableSilences](t, req, http.StatusOK)
+}
+
+func (a apiClient) DeleteSilence(t *testing.T, id string) (any, int, string) {
+	t.Helper()
+	req, err := http.NewRequest(http.MethodDelete, fmt.Sprintf("%s/api/alertmanager/grafana/api/v2/silence/%s", a.url, id), nil)
+	require.NoError(t, err)
+
+	type dynamic struct {
+		Message string `json:"message"`
+	}
+
+	return sendRequest[dynamic](t, req, http.StatusOK)
 }
 
 func (a apiClient) GetRulesGroup(t *testing.T, folder string, group string) apimodels.RuleGroupConfigResponse {
@@ -595,6 +681,30 @@ func (a apiClient) ExportRulesWithStatus(t *testing.T, params *apimodels.AlertRu
 	return resp.StatusCode, string(b)
 }
 
+func (a apiClient) GetRuleGroupProvisioning(t *testing.T, folderUID string, groupName string) (apimodels.AlertRuleGroup, int, string) {
+	t.Helper()
+
+	req, err := http.NewRequest(http.MethodGet, fmt.Sprintf("%s/api/v1/provisioning/folder/%s/rule-groups/%s", a.url, folderUID, groupName), nil)
+	require.NoError(t, err)
+
+	return sendRequest[apimodels.AlertRuleGroup](t, req, http.StatusOK)
+}
+
+func (a apiClient) CreateOrUpdateRuleGroupProvisioning(t *testing.T, group apimodels.AlertRuleGroup) (apimodels.AlertRuleGroup, int, string) {
+	t.Helper()
+
+	buf := bytes.Buffer{}
+	enc := json.NewEncoder(&buf)
+	err := enc.Encode(group)
+	require.NoError(t, err)
+
+	req, err := http.NewRequest(http.MethodPut, fmt.Sprintf("%s/api/v1/provisioning/folder/%s/rule-groups/%s", a.url, group.FolderUID, group.Title), &buf)
+	require.NoError(t, err)
+	req.Header.Add("Content-Type", "application/json")
+
+	return sendRequest[apimodels.AlertRuleGroup](t, req, http.StatusOK)
+}
+
 func (a apiClient) SubmitRuleForBacktesting(t *testing.T, config apimodels.BacktestConfig) (int, string) {
 	t.Helper()
 	buf := bytes.Buffer{}
@@ -762,7 +872,15 @@ func (a apiClient) GetRouteWithStatus(t *testing.T) (apimodels.Route, int, strin
 	return sendRequest[apimodels.Route](t, req, http.StatusOK)
 }
 
-func (a apiClient) UpdateRouteWithStatus(t *testing.T, route apimodels.Route) (int, string) {
+func (a apiClient) GetRoute(t *testing.T) apimodels.Route {
+	t.Helper()
+
+	route, status, data := a.GetRouteWithStatus(t)
+	requireStatusCode(t, http.StatusOK, status, data)
+	return route
+}
+
+func (a apiClient) UpdateRouteWithStatus(t *testing.T, route apimodels.Route, noProvenance bool) (int, string) {
 	t.Helper()
 
 	buf := bytes.Buffer{}
@@ -772,6 +890,9 @@ func (a apiClient) UpdateRouteWithStatus(t *testing.T, route apimodels.Route) (i
 
 	req, err := http.NewRequest(http.MethodPut, fmt.Sprintf("%s/api/v1/provisioning/policies", a.url), &buf)
 	req.Header.Add("Content-Type", "application/json")
+	if noProvenance {
+		req.Header.Add("X-Disable-Provenance", "true")
+	}
 	require.NoError(t, err)
 
 	client := &http.Client{}
@@ -786,6 +907,12 @@ func (a apiClient) UpdateRouteWithStatus(t *testing.T, route apimodels.Route) (i
 	return resp.StatusCode, string(body)
 }
 
+func (a apiClient) UpdateRoute(t *testing.T, route apimodels.Route, noProvenance bool) {
+	t.Helper()
+	status, data := a.UpdateRouteWithStatus(t, route, noProvenance)
+	requireStatusCode(t, http.StatusAccepted, status, data)
+}
+
 func (a apiClient) GetRuleHistoryWithStatus(t *testing.T, ruleUID string) (data.Frame, int, string) {
 	t.Helper()
 	u, err := url.Parse(fmt.Sprintf("%s/api/v1/rules/history", a.url))
@@ -840,6 +967,44 @@ func (a apiClient) EnsureReceiver(t *testing.T, receiver apimodels.EmbeddedConta
 	require.Equalf(t, http.StatusAccepted, status, body)
 }
 
+func (a apiClient) ExportReceiver(t *testing.T, name string, format string, decrypt bool) string {
+	t.Helper()
+	u, err := url.Parse(fmt.Sprintf("%s/api/v1/provisioning/contact-points/export", a.url))
+	require.NoError(t, err)
+	q := url.Values{}
+	q.Set("name", name)
+	q.Set("format", format)
+	q.Set("decrypt", fmt.Sprintf("%v", decrypt))
+	u.RawQuery = q.Encode()
+
+	req, err := http.NewRequest(http.MethodGet, u.String(), nil)
+	require.NoError(t, err)
+
+	client := &http.Client{}
+	resp, err := client.Do(req)
+	require.NoError(t, err)
+
+	defer func() {
+		_ = resp.Body.Close()
+	}()
+	body, err := io.ReadAll(resp.Body)
+	require.NoError(t, err)
+
+	requireStatusCode(t, http.StatusOK, resp.StatusCode, string(body))
+	return string(body)
+}
+
+func (a apiClient) ExportReceiverTyped(t *testing.T, name string, decrypt bool) apimodels.ContactPointExport {
+	t.Helper()
+
+	response := a.ExportReceiver(t, name, "json", decrypt)
+
+	var export apimodels.AlertingFileExport
+	require.NoError(t, json.Unmarshal([]byte(response), &export))
+	require.Len(t, export.ContactPoints, 1)
+	return export.ContactPoints[0]
+}
+
 func (a apiClient) GetAlertmanagerConfigWithStatus(t *testing.T) (apimodels.GettableUserConfig, int, string) {
 	t.Helper()
 	req, err := http.NewRequest(http.MethodGet, fmt.Sprintf("%s/api/alertmanager/grafana/config/api/v1/alerts", a.url), nil)
@@ -856,6 +1021,7 @@ func (a apiClient) GetActiveAlertsWithStatus(t *testing.T) (apimodels.AlertGroup
 }
 
 func sendRequest[T any](t *testing.T, req *http.Request, successStatusCode int) (T, int, string) {
+	t.Helper()
 	client := &http.Client{}
 	resp, err := client.Do(req)
 	require.NoError(t, err)
@@ -877,5 +1043,26 @@ func sendRequest[T any](t *testing.T, req *http.Request, successStatusCode int)
 }
 
 func requireStatusCode(t *testing.T, expected, actual int, response string) {
+	t.Helper()
 	require.Equalf(t, expected, actual, "Unexpected status. Response: %s", response)
 }
+
+func createUser(t *testing.T, db db.DB, cfg *setting.Cfg, cmd user.CreateUserCommand) int64 {
+	t.Helper()
+
+	cfg.AutoAssignOrg = true
+	cfg.AutoAssignOrgId = 1
+
+	quotaService := quotaimpl.ProvideService(db, cfg)
+	orgService, err := orgimpl.ProvideService(db, cfg, quotaService)
+	require.NoError(t, err)
+	usrSvc, err := userimpl.ProvideService(
+		db, orgService, cfg, nil, nil, tracing.InitializeTracerForTest(),
+		quotaService, supportbundlestest.NewFakeBundleService(),
+	)
+	require.NoError(t, err)
+
+	u, err := usrSvc.Create(context.Background(), &cmd)
+	require.NoError(t, err)
+	return u.ID
+}
