@@ -139,15 +139,24 @@ func TestIntegrationSimpleQuery(t *testing.T) {
 
 		require.Error(t, err, "expecting a 400")
 		require.JSONEq(t, `{
-			"status": "Failure",
-			"metadata": {},
-			"message": "did not execute expression [Y] due to a failure to of the dependent expression or query [X]",
-			"reason": "BadRequest",
-			"details": { "group": "query.grafana.app" },
-			"code": 400,
-			"messageId": "sse.dependencyError",
-			"extra": { "depRefId": "X", "refId": "Y" }
-		  }`, string(body))
+			"results": {
+				"A": {
+					"error": "[sse.dependencyError] did not execute expression [Y] due to a failure to of the dependent expression or query [X]",
+					"status": 400,
+					"errorSource": ""
+				}
+			}
+		}`, string(body))
+		// require.JSONEq(t, `{
+		// 	"status": "Failure",
+		// 	"metadata": {},
+		// 	"message": "did not execute expression [Y] due to a failure to of the dependent expression or query [X]",
+		// 	"reason": "BadRequest",
+		// 	"details": { "group": "query.grafana.app" },
+		// 	"code": 400,
+		// 	"messageId": "sse.dependencyError",
+		// 	"extra": { "depRefId": "X", "refId": "Y" }
+		//   }`, string(body))
 
 		statusCode := -1
 		contentType := "?"
