@@ -1,6 +1,8 @@
 package mocks
 
 import (
+	"context"
+
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/models/resources"
 	"github.com/stretchr/testify/mock"
 )
@@ -9,7 +11,7 @@ type AccountsServiceMock struct {
 	mock.Mock
 }
 
-func (a *AccountsServiceMock) GetAccountsForCurrentUserOrRole() ([]resources.ResourceResponse[resources.Account], error) {
+func (a *AccountsServiceMock) GetAccountsForCurrentUserOrRole(ctx context.Context) ([]resources.ResourceResponse[resources.Account], error) {
 	args := a.Called()
 
 	return args.Get(0).([]resources.ResourceResponse[resources.Account]), args.Error(1)
