@@ -1,6 +1,8 @@
 package mocks
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/cloudwatch"
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/models/resources"
 	"github.com/stretchr/testify/mock"
@@ -10,7 +12,7 @@ type FakeMetricsClient struct {
 	mock.Mock
 }
 
-func (m *FakeMetricsClient) ListMetricsWithPageLimit(params *cloudwatch.ListMetricsInput) ([]resources.MetricResponse, error) {
+func (m *FakeMetricsClient) ListMetricsWithPageLimit(ctx context.Context, params *cloudwatch.ListMetricsInput) ([]resources.MetricResponse, error) {
 	args := m.Called(params)
 	return args.Get(0).([]resources.MetricResponse), args.Error(1)
 }
