@@ -1,9 +1,11 @@
 package services
 
 import (
+	"context"
 	"sort"
 
 	"github.com/aws/aws-sdk-go/service/ec2"
+	"github.com/grafana/grafana-plugin-sdk-go/backend/log"
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/constants"
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/models"
 	"github.com/grafana/grafana/pkg/tsdb/cloudwatch/models/resources"
@@ -11,11 +13,13 @@ import (
 
 type RegionsService struct {
 	models.EC2APIProvider
+	log.Logger
 }
 
-func NewRegionsService(ec2client models.EC2APIProvider) models.RegionsAPIProvider {
+func NewRegionsService(ec2client models.EC2APIProvider, logger log.Logger) models.RegionsAPIProvider {
 	return &RegionsService{
 		ec2client,
+		logger,
 	}
 }
 
@@ -27,14 +31,17 @@ func mergeEC2RegionsAndConstantRegions(regions map[string]struct{}, ec2Regions [
 	}
 }
 
-func (r *RegionsService) GetRegions() ([]resources.ResourceResponse[resources.Region], error) {
+func (r *RegionsService) GetRegions(ctx context.Context) ([]resources.ResourceResponse[resources.Region], error) {
 	regions := constants.Regions()
 
 	result := make([]resources.ResourceResponse[resources.Region], 0)
 
-	ec2Regions, err := r.DescribeRegions(&ec2.DescribeRegionsInput{})
+	ec2Regions, err := r.DescribeRegionsWithContext(ctx, &ec2.DescribeRegionsInput{})
+	// we ignore this error and always send default regions
+	// we only fetch incase a user has enabled additional regions
+	// but we still log it in case the user is expecting to fetch regions specific to their account and are unable to
 	if err != nil {
-		return nil, err
+		r.Error("Failed to get regions: ", "error", err)
 	}
 
 	mergeEC2RegionsAndConstantRegions(regions, ec2Regions.Regions)
