@@ -1,13 +1,14 @@
-import React from 'react';
-
 import { Page } from 'app/core/components/Page/Page';
+import { Trans } from 'app/core/internationalization';
 
 export default function FeatureTogglePage() {
   return (
     <Page navId="correlations">
       <Page.Contents>
-        <h1>Correlations are disabled</h1>
-        To enable Correlations, add it in the Grafana config:
+        <h1>
+          <Trans i18nKey="correlations.page-heading">Correlations are disabled</Trans>
+        </h1>
+        <Trans i18nKey="correlations.page-content">To enable Correlations, add it in the Grafana config:</Trans>
         <div>
           <pre>
             {`[feature_toggles]
