@@ -6,11 +6,13 @@ const ESLintPlugin = require('eslint-webpack-plugin');
 const ForkTsCheckerWebpackPlugin = require('fork-ts-checker-webpack-plugin');
 const MiniCssExtractPlugin = require('mini-css-extract-plugin');
 const path = require('path');
-const { DefinePlugin } = require('webpack');
+const { DefinePlugin, EnvironmentPlugin } = require('webpack');
 const WebpackAssetsManifest = require('webpack-assets-manifest');
+const LiveReloadPlugin = require('webpack-livereload-plugin');
 const { merge } = require('webpack-merge');
 const WebpackBar = require('webpackbar');
 
+const getEnvConfig = require('./env-util.js');
 const common = require('./webpack.common.js');
 const esbuildTargets = resolveToEsbuildTarget(browserslist(), { printUnknownTargets: false });
 // esbuild-loader 3.0.0+ requires format to be set to prevent it
@@ -18,6 +20,7 @@ const esbuildTargets = resolveToEsbuildTarget(browserslist(), { printUnknownTarg
 const esbuildOptions = {
   target: esbuildTargets,
   format: undefined,
+  jsx: 'automatic',
 };
 
 // To speed up webpack and prevent unnecessary rebuilds we ignore decoupled packages
@@ -26,6 +29,8 @@ function getDecoupledPlugins() {
   return packages.filter((pkg) => pkg.dir.includes('plugins/datasource')).map((pkg) => `${pkg.dir}/**`);
 }
 
+const envConfig = getEnvConfig();
+
 module.exports = (env = {}) => {
   return merge(common, {
     devtool: 'source-map',
@@ -45,12 +50,16 @@ module.exports = (env = {}) => {
     resolve: {
       alias: {
         // Packages linked for development need react to be resolved from the same location
-        react: require.resolve('react'),
+        react: path.resolve('./node_modules/react'),
 
         // Also Grafana packages need to be resolved from the same location so they share
         // the same singletons
         '@grafana/runtime': path.resolve(__dirname, '../../packages/grafana-runtime'),
         '@grafana/data': path.resolve(__dirname, '../../packages/grafana-data'),
+
+        // This is required to correctly resolve react-router-dom when linking with
+        //  local version of @grafana/scenes
+        'react-router-dom': path.resolve('./node_modules/react-router-dom'),
       },
     },
 
@@ -66,7 +75,7 @@ module.exports = (env = {}) => {
         },
         require('./sass.rule.js')({
           sourceMap: false,
-          preserveUrl: false,
+          preserveUrl: true,
         }),
       ],
     },
@@ -97,13 +106,24 @@ module.exports = (env = {}) => {
     },
 
     plugins: [
+      ...(parseInt(env.liveReload, 10)
+        ? [
+            new LiveReloadPlugin({
+              appendScriptTag: true,
+              useSourceHash: true,
+              hostname: 'localhost',
+              protocol: 'http',
+              port: 35750,
+            }),
+          ]
+        : []),
       parseInt(env.noTsCheck, 10)
         ? new DefinePlugin({}) // bogus plugin to satisfy webpack API
         : new ForkTsCheckerWebpackPlugin({
             async: true, // don't block webpack emit
             typescript: {
               mode: 'write-references',
-              memoryLimit: 4096,
+              memoryLimit: 5096,
               diagnosticOptions: {
                 semantic: true,
                 syntactic: true,
@@ -116,6 +136,7 @@ module.exports = (env = {}) => {
             cache: true,
             lintDirtyModulesOnly: true, // don't lint on start, only lint changed files
             extensions: ['.ts', '.tsx'],
+            configType: 'flat',
           }),
       new MiniCssExtractPlugin({
         filename: 'grafana.[name].[contenthash].css',
@@ -134,6 +155,7 @@ module.exports = (env = {}) => {
         color: '#eb7b18',
         name: 'Grafana',
       }),
+      new EnvironmentPlugin(envConfig),
     ],
 
     stats: 'minimal',
